@@ -7,9 +7,9 @@
 
 #include "ldapurl.h"
 
-#include "ldap_debug.h"
+#include "ldap_core_debug.h"
 
-using namespace KLDAP;
+using namespace KLDAPCore;
 
 class Q_DECL_HIDDEN LdapUrl::LdapUrlPrivate
 {
@@ -74,7 +74,7 @@ LdapDN LdapUrl::dn() const
     if (tmp.startsWith(QLatin1Char('/'))) {
         tmp = tmp.mid(1);
     }
-    LdapDN tmpDN(tmp);
+    const LdapDN tmpDN(tmp);
     return tmpDN;
 }
 
