@@ -10,17 +10,17 @@
 #include "ldapclient.h"
 #include "ldapclient_debug.h"
 
-#include <kldap/ldapobject.h>
-#include <kldap/ldapserver.h>
-#include <kldap/ldapurl.h>
-#include <kldap/ldif.h>
+#include <kldapcore/ldapobject.h>
+#include <kldapcore/ldapserver.h>
+#include <kldapcore/ldapurl.h>
+#include <kldapcore/ldif.h>
 
-#include <KIO/Job>
+#include <KIO/TransferJob>
 
 #include <QPointer>
 
-using namespace KLDAP;
-
+using namespace KLDAPCore;
+using namespace KLDAPWidgets;
 class Q_DECL_HIDDEN LdapClient::LdapClientPrivate
 {
 public:
@@ -35,27 +35,27 @@ public:
     }
 
     void cancelQuery();
-    
+
     void startParseLDIF();
     void parseLDIF(const QByteArray &data);
     void endParseLDIF();
     void finishCurrentObject();
 
     void slotData(KIO::Job *, const QByteArray &data);
-    void slotInfoMessage(KJob *, const QString &info, const QString &);
+    void slotInfoMessage(KJob *, const QString &info);
     void slotDone();
 
     LdapClient *const q;
 
-    KLDAP::LdapServer mServer;
+    KLDAPCore::LdapServer mServer;
     QString mScope;
     QStringList mAttrs;
 
     QPointer<KJob> mJob = nullptr;
     bool mActive = false;
 
-    KLDAP::LdapObject mCurrentObject;
-    KLDAP::Ldif mLdif;
+    KLDAPCore::LdapObject mCurrentObject;
+    KLDAPCore::Ldif mLdif;
     int mClientNumber = 0;
     int mCompletionWeight = 0;
 };
@@ -75,12 +75,12 @@ bool LdapClient::isActive() const
     return d->mActive;
 }
 
-void LdapClient::setServer(const KLDAP::LdapServer &server)
+void LdapClient::setServer(const KLDAPCore::LdapServer &server)
 {
     d->mServer = server;
 }
 
-const KLDAP::LdapServer LdapClient::server() const
+const KLDAPCore::LdapServer LdapClient::server() const
 {
     return d->mServer;
 }
@@ -104,10 +104,10 @@ void LdapClient::setScope(const QString &scope)
 void LdapClient::startQuery(const QString &filter)
 {
     cancelQuery();
-    KLDAP::LdapUrl url{d->mServer.url()};
+    KLDAPCore::LdapUrl url{d->mServer.url()};
 
     url.setAttributes(d->mAttrs);
-    url.setScope(d->mScope == QLatin1String("one") ? KLDAP::LdapUrl::One : KLDAP::LdapUrl::Sub);
+    url.setScope(d->mScope == QLatin1String("one") ? KLDAPCore::LdapUrl::One : KLDAPCore::LdapUrl::Sub);
     const QString userFilter = url.filter();
     QString finalFilter = filter;
     // combine the filter set by the user in the config dialog (url.filter()) and the filter from this query
@@ -125,8 +125,8 @@ void LdapClient::startQuery(const QString &filter)
     connect(transfertJob, &KIO::TransferJob::data, this, [this](KIO::Job *job, const QByteArray &data) {
         d->slotData(job, data);
     });
-    connect(d->mJob.data(), &KIO::TransferJob::infoMessage, this, [this](KJob *job, const QString &str, const QString &val) {
-        d->slotInfoMessage(job, str, val);
+    connect(d->mJob.data(), &KIO::TransferJob::infoMessage, this, [this](KJob *job, const QString &message) {
+        d->slotInfoMessage(job, message);
     });
     connect(d->mJob.data(), &KIO::TransferJob::result, this, [this]() {
         d->slotDone();
@@ -153,7 +153,7 @@ void LdapClient::LdapClientPrivate::slotData(KIO::Job *, const QByteArray &data)
     parseLDIF(data);
 }
 
-void LdapClient::LdapClientPrivate::slotInfoMessage(KJob *, const QString &info, const QString &)
+void LdapClient::LdapClientPrivate::slotInfoMessage(KJob *, const QString &info)
 {
     qCDebug(LDAPCLIENT_LOG) << "Job said :" << info;
 }
@@ -185,9 +185,9 @@ void LdapClient::LdapClientPrivate::endParseLDIF()
 void LdapClient::LdapClientPrivate::finishCurrentObject()
 {
     mCurrentObject.setDn(mLdif.dn());
-    KLDAP::LdapAttrValue objectclasses;
-    const KLDAP::LdapAttrMap::ConstIterator end = mCurrentObject.attributes().constEnd();
-    for (KLDAP::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().constBegin(); it != end; ++it) {
+    KLDAPCore::LdapAttrValue objectclasses;
+    const KLDAPCore::LdapAttrMap::ConstIterator end = mCurrentObject.attributes().constEnd();
+    for (KLDAPCore::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().constBegin(); it != end; ++it) {
         if (it.key().toLower() == QLatin1String("objectclass")) {
             objectclasses = it.value();
             break;
@@ -195,8 +195,8 @@ void LdapClient::LdapClientPrivate::finishCurrentObject()
     }
 
     bool groupofnames = false;
-    const KLDAP::LdapAttrValue::ConstIterator endValue(objectclasses.constEnd());
-    for (KLDAP::LdapAttrValue::ConstIterator it = objectclasses.constBegin(); it != endValue; ++it) {
+    const KLDAPCore::LdapAttrValue::ConstIterator endValue(objectclasses.constEnd());
+    for (KLDAPCore::LdapAttrValue::ConstIterator it = objectclasses.constBegin(); it != endValue; ++it) {
         const QByteArray sClass = (*it).toLower();
         if (sClass == "groupofnames" || sClass == "kolabgroupofnames") {
             groupofnames = true;
@@ -204,7 +204,7 @@ void LdapClient::LdapClientPrivate::finishCurrentObject()
     }
 
     if (groupofnames) {
-        KLDAP::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().find(QStringLiteral("mail"));
+        KLDAPCore::LdapAttrMap::ConstIterator it = mCurrentObject.attributes().find(QStringLiteral("mail"));
         if (it == mCurrentObject.attributes().end()) {
             // No explicit mail address found so far?
             // Fine, then we use the address stored in the DN.
@@ -240,24 +240,24 @@ void LdapClient::LdapClientPrivate::parseLDIF(const QByteArray &data)
     } else {
         mLdif.endLdif();
     }
-    KLDAP::Ldif::ParseValue ret;
+    KLDAPCore::Ldif::ParseValue ret;
     QString name;
     do {
         ret = mLdif.nextItem();
         switch (ret) {
-        case KLDAP::Ldif::Item: {
+        case KLDAPCore::Ldif::Item: {
             name = mLdif.attr();
             const QByteArray value = mLdif.value();
             mCurrentObject.addValue(name, value);
             break;
         }
-        case KLDAP::Ldif::EndEntry:
+        case KLDAPCore::Ldif::EndEntry:
             finishCurrentObject();
             break;
         default:
             break;
         }
-    } while (ret != KLDAP::Ldif::MoreData);
+    } while (ret != KLDAPCore::Ldif::MoreData);
 }
 
 int LdapClient::clientNumber() const
