@@ -4,7 +4,7 @@
  *
  * Ported to KABC by Daniel Molkentin <molkentin@kde.org>
  *
- * SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -16,24 +16,21 @@
 
 #include "ldapclient.h"
 
-#include <kldap/ldapserver.h>
-#include <kldap/ldapurl.h>
-#include <kldap/ldif.h>
+#include <kldapcore/ldapserver.h>
+#include <kldapcore/ldapurl.h>
+#include <kldapcore/ldif.h>
 
 #include <KConfig>
 #include <KConfigGroup>
 #include <KDirWatch>
 #include <KProtocolInfo>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <Kdelibs4ConfigMigrator>
-#endif
 
 #include <KIO/Job>
 
 #include <QStandardPaths>
 #include <QTimer>
 
-using namespace KLDAP;
+using namespace KLDAPWidgets;
 
 class Q_DECL_HIDDEN LdapClientSearch::LdapClientSearchPrivate
 {
@@ -50,7 +47,7 @@ public:
     void finish();
     void makeSearchData(QStringList &ret, LdapResult::List &resList);
 
-    void slotLDAPResult(const KLDAP::LdapClient &client, const KLDAP::LdapObject &);
+    void slotLDAPResult(const KLDAPWidgets::LdapClient &client, const KLDAPCore::LdapObject &);
     void slotLDAPError(const QString &);
     void slotLDAPDone();
     void slotDataTimer();
@@ -87,12 +84,6 @@ LdapClientSearch::~LdapClientSearch() = default;
 
 void LdapClientSearch::LdapClientSearchPrivate::init(const QStringList &attributes)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    Kdelibs4ConfigMigrator migrate(QStringLiteral("ldapsettings"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("kabldaprc"));
-    migrate.migrate();
-#endif
-
     if (!KProtocolInfo::isKnownProtocol(QUrl(QStringLiteral("ldap://localhost")))) {
         mNoLDAPLookup = true;
         return;
@@ -121,7 +112,7 @@ void LdapClientSearch::LdapClientSearchPrivate::readWeighForClient(LdapClient *c
 
 void LdapClientSearch::updateCompletionWeights()
 {
-    KConfigGroup config(KLDAP::LdapClientSearchConfig::config(), "LDAP");
+    KConfigGroup config(KLDAPWidgets::LdapClientSearchConfig::config(), QStringLiteral("LDAP"));
     for (int i = 0, total = d->mClients.size(); i < total; ++i) {
         d->readWeighForClient(d->mClients[i], config, i);
     }
@@ -168,7 +159,7 @@ void LdapClientSearch::LdapClientSearchPrivate::readConfig()
     mClients.clear();
 
     // stolen from KAddressBook
-    KConfigGroup config(KLDAP::LdapClientSearchConfig::config(), "LDAP");
+    KConfigGroup config(KLDAPWidgets::LdapClientSearchConfig::config(), QStringLiteral("LDAP"));
     const int numHosts = config.readEntry("NumSelectedHosts", 0);
     if (!numHosts) {
         mNoLDAPLookup = true;
@@ -187,7 +178,7 @@ void LdapClientSearch::LdapClientSearchPrivate::readConfig()
 
             ldapClient->setAttributes(mAttributes);
 
-            q->connect(ldapClient, &LdapClient::result, q, [this](const LdapClient &client, const KLDAP::LdapObject &obj) {
+            q->connect(ldapClient, &LdapClient::result, q, [this](const LdapClient &client, const KLDAPCore::LdapObject &obj) {
                 slotLDAPResult(client, obj);
             });
             q->connect(ldapClient, &LdapClient::done, q, [this]() {
@@ -260,7 +251,7 @@ void LdapClientSearch::cancelSearch()
     d->mResults.clear();
 }
 
-void LdapClientSearch::LdapClientSearchPrivate::slotLDAPResult(const LdapClient &client, const KLDAP::LdapObject &obj)
+void LdapClientSearch::LdapClientSearchPrivate::slotLDAPResult(const LdapClient &client, const KLDAPCore::LdapObject &obj)
 {
     LdapResultObject result;
     result.client = &client;
@@ -311,7 +302,7 @@ void LdapClientSearch::LdapClientSearchPrivate::finish()
     Q_EMIT q->searchDone();
 }
 
-void LdapClientSearch::LdapClientSearchPrivate::makeSearchData(QStringList &ret, LdapResult::List &resList)
+void LdapClientSearch::LdapClientSearchPrivate::makeSearchData(QStringList &ret, KLDAPWidgets::LdapResult::List &resList)
 {
     LdapResultObject::List::ConstIterator it1(mResults.constBegin());
     const LdapResultObject::List::ConstIterator end1(mResults.constEnd());
@@ -327,7 +318,7 @@ void LdapClientSearch::LdapClientSearchPrivate::makeSearchData(QStringList &ret,
 
         // qCDebug(LDAPCLIENT_LOG) <<"\n\nLdapClientSearch::makeSearchData()";
 
-        KLDAP::LdapAttrMap::ConstIterator it2;
+        KLDAPCore::LdapAttrMap::ConstIterator it2;
         for (it2 = (*it1).object.attributes().constBegin(); it2 != (*it1).object.attributes().constEnd(); ++it2) {
             QByteArray val = (*it2).first();
             int len = val.size();
@@ -363,7 +354,7 @@ void LdapClientSearch::LdapClientSearchPrivate::makeSearchData(QStringList &ret,
                 wasDC = true;
             } else if (it2.key() == QLatin1String("mail")) {
                 mail = tmp;
-                KLDAP::LdapAttrValue::ConstIterator it3 = it2.value().constBegin();
+                KLDAPCore::LdapAttrValue::ConstIterator it3 = it2.value().constBegin();
                 for (; it3 != it2.value().constEnd(); ++it3) {
                     mails.append(QString::fromUtf8((*it3).data(), (*it3).size()));
                 }
