@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -9,15 +9,11 @@
 
 #include <KConfig>
 #include <KLocalizedString>
-#include <kldap/ldapdn.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <qt5keychain/keychain.h>
-#else
+#include <kldapcore/ldapdn.h>
 #include <qt6keychain/keychain.h>
-#endif
 using namespace QKeychain;
 
-using namespace KLDAP;
+using namespace KLDAPWidgets;
 LdapClientSearchConfigReadConfigJob::LdapClientSearchConfigReadConfigJob(QObject *parent)
     : QObject(parent)
 {
@@ -93,7 +89,7 @@ void LdapClientSearchConfigReadConfigJob::readConfig()
 
     const QString base = mConfig.readEntry(prefix + QStringLiteral("Base%1").arg(mServerIndex), QString()).trimmed();
     if (!base.isEmpty()) {
-        mServer.setBaseDn(KLDAP::LdapDN(base));
+        mServer.setBaseDn(KLDAPCore::LdapDN(base));
     }
 
     const QString user = mConfig.readEntry(prefix + QStringLiteral("User%1").arg(mServerIndex), QString()).trimmed();
@@ -105,66 +101,25 @@ void LdapClientSearchConfigReadConfigJob::readConfig()
     if (!bindDN.isEmpty()) {
         mServer.setBindDn(bindDN);
     }
-#if 0 // Port
-    const QString pwdBindBNEntry = prefix + QStringLiteral("PwdBind%1").arg(mServerIndex);
-    QString pwdBindDN = mConfig.readEntry(pwdBindBNEntry, QString());
-    if (!pwdBindDN.isEmpty()) {
-        if (d->askWallet && KMessageBox::Yes == KMessageBox::questionYesNo(nullptr, i18n("LDAP password is stored as clear text, do you want to store it in kwallet?"),
-                                                                           i18n("Store clear text password in Wallet"),
-                                                                           KStandardGuiItem::yes(),
-                                                                           KStandardGuiItem::no(),
-                                                                           QStringLiteral("DoAskToStoreToWallet"))) {
-            d->wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0);
-            if (d->wallet) {
-                connect(d->wallet, &KWallet::Wallet::walletClosed, this, &LdapClientSearchConfig::slotWalletClosed);
-                d->useWallet = true;
-                if (!d->wallet->hasFolder(QStringLiteral("ldapclient"))) {
-                    d->wallet->createFolder(QStringLiteral("ldapclient"));
-                }
-                d->wallet->setFolder(QStringLiteral("ldapclient"));
-                d->wallet->writePassword(pwdBindBNEntry, pwdBindDN);
-                mConfig.deleteEntry(pwdBindBNEntry);
-                mConfig.sync();
-            }
-        }
-        mServer.setPassword(pwdBindDN);
-    } else if (d->askWallet) { //Look at in Wallet
-        //Move as async here.
-        d->wallet = KWallet::Wallet::openWallet(KWallet::Wallet::LocalWallet(), 0);
-        if (d->wallet) {
-            d->useWallet = true;
-            if (!d->wallet->setFolder(QStringLiteral("ldapclient"))) {
-                d->wallet->createFolder(QStringLiteral("ldapclient"));
-                d->wallet->setFolder(QStringLiteral("ldapclient"));
-            }
-            d->wallet->readPassword(pwdBindBNEntry, pwdBindDN);
-            if (!pwdBindDN.isEmpty()) {
-                mServer.setPassword(pwdBindDN);
-            }
-        } else {
-            d->useWallet = false;
-        }
-    }
-#endif
     mServer.setTimeLimit(mConfig.readEntry(prefix + QStringLiteral("TimeLimit%1").arg(mServerIndex), 0));
     mServer.setSizeLimit(mConfig.readEntry(prefix + QStringLiteral("SizeLimit%1").arg(mServerIndex), 0));
     mServer.setPageSize(mConfig.readEntry(prefix + QStringLiteral("PageSize%1").arg(mServerIndex), 0));
     mServer.setVersion(mConfig.readEntry(prefix + QStringLiteral("Version%1").arg(mServerIndex), 3));
 
     QString tmp = mConfig.readEntry(prefix + QStringLiteral("Security%1").arg(mServerIndex), QStringLiteral("None"));
-    mServer.setSecurity(KLDAP::LdapServer::None);
+    mServer.setSecurity(KLDAPCore::LdapServer::None);
     if (tmp == QLatin1String("SSL")) {
-        mServer.setSecurity(KLDAP::LdapServer::SSL);
+        mServer.setSecurity(KLDAPCore::LdapServer::SSL);
     } else if (tmp == QLatin1String("TLS")) {
-        mServer.setSecurity(KLDAP::LdapServer::TLS);
+        mServer.setSecurity(KLDAPCore::LdapServer::TLS);
     }
 
     tmp = mConfig.readEntry(prefix + QStringLiteral("Auth%1").arg(mServerIndex), QStringLiteral("Anonymous"));
-    mServer.setAuth(KLDAP::LdapServer::Anonymous);
+    mServer.setAuth(KLDAPCore::LdapServer::Anonymous);
     if (tmp == QLatin1String("Simple")) {
-        mServer.setAuth(KLDAP::LdapServer::Simple);
+        mServer.setAuth(KLDAPCore::LdapServer::Simple);
     } else if (tmp == QLatin1String("SASL")) {
-        mServer.setAuth(KLDAP::LdapServer::SASL);
+        mServer.setAuth(KLDAPCore::LdapServer::SASL);
     }
 
     mServer.setMech(mConfig.readEntry(prefix + QStringLiteral("Mech%1").arg(mServerIndex), QString()));
@@ -174,19 +129,18 @@ void LdapClientSearchConfigReadConfigJob::readConfig()
     const QString pwdBindBNEntry = prefix + QStringLiteral("PwdBind%1").arg(mServerIndex);
 
     auto readJob = new ReadPasswordJob(QStringLiteral("ldapclient"), this);
-    connect(readJob, &Job::finished, this, &LdapClientSearchConfigReadConfigJob::readLdapPasswordFinished);
+    connect(readJob, &Job::finished, this, [this, pwdBindBNEntry](QKeychain::Job *baseJob) {
+        auto job = qobject_cast<ReadPasswordJob *>(baseJob);
+        Q_ASSERT(job);
+        if (!job->error()) {
+            mServer.setPassword(job->textData());
+        } else {
+            qCWarning(LDAPCLIENT_LOG) << "We have an error during reading password " << job->errorString() << " password key " << pwdBindBNEntry;
+        }
+        readLdapClientConfigFinished();
+    });
     readJob->setKey(pwdBindBNEntry);
     readJob->start();
 }
 
-void LdapClientSearchConfigReadConfigJob::readLdapPasswordFinished(QKeychain::Job *baseJob)
-{
-    auto job = qobject_cast<ReadPasswordJob *>(baseJob);
-    Q_ASSERT(job);
-    if (!job->error()) {
-        mServer.setPassword(job->textData());
-    } else {
-        qCWarning(LDAPCLIENT_LOG) << "We have an error during reading password " << job->errorString();
-    }
-    readLdapClientConfigFinished();
-}
+#include "moc_ldapclientsearchconfigreadconfigjob.cpp"
