@@ -31,6 +31,10 @@
 #include <QtHttpServer/qhttpserverrequest.h>
 #include <QtHttpServer/qhttpserverrouterrule.h>
 
+#if QT_CONFIG(concurrent)
+#  include <QtHttpServer/qhttpserverfutureresponse.h>
+#endif
+
 #include <private/qhttpserverrouterrule_p.h>
 #include <private/qhttpserverliterals_p.h>
 
@@ -46,6 +50,7 @@
 #include <QtCore/qjsonobject.h>
 #include <QtCore/qjsonvalue.h>
 #include <QtCore/qjsonarray.h>
+#include <QtCore/qtimer.h>
 
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qnetworkreply.h>
@@ -129,6 +134,8 @@ private slots:
     void routeExtraHeaders();
     void invalidRouterArguments();
     void checkRouteLambdaCapture();
+    void afterRequest();
+    void disconnectedInEventLoop();
 
 private:
     void checkReply(QNetworkReply *reply, const QString &response);
@@ -149,6 +156,19 @@ struct CustomArg {
 
 void tst_QHttpServer::initTestCase()
 {
+
+    httpserver.route("/req-and-resp", [] (QHttpServerResponder &&resp,
+                                          const QHttpServerRequest &req) {
+        resp.write(req.body(),
+                   QHttpServerLiterals::contentTypeTextHtml());
+    });
+
+    httpserver.route("/resp-and-req", [] (const QHttpServerRequest &req,
+                                          QHttpServerResponder &&resp) {
+        resp.write(req.body(),
+                   QHttpServerLiterals::contentTypeTextHtml());
+    });
+
     httpserver.route("/test", [] (QHttpServerResponder &&responder) {
         responder.write("test msg",
                         QHttpServerLiterals::contentTypeTextHtml());
@@ -172,12 +192,8 @@ void tst_QHttpServer::initTestCase()
     });
 
     httpserver.route("/any", "All", [] (const QHttpServerRequest &request) {
-        static const int index = QHttpServerRequest::staticMetaObject.indexOfEnumerator("Method");
-        if (index == -1)
-            return "Error: Could not find enum Method";
-
-        static const QMetaEnum en = QHttpServerRequest::staticMetaObject.enumerator(index);
-        return en.valueToKey(static_cast<int>(request.method()));
+        static const auto metaEnum = QMetaEnum::fromType<QHttpServerRequest::Method>();
+        return metaEnum.valueToKey(static_cast<int>(request.method()));
     });
 
     httpserver.route("/page/", [] (const qint32 number) {
@@ -280,8 +296,26 @@ void tst_QHttpServer::initTestCase()
         return resp;
     });
 
-    int port = httpserver.listen();
-    if (port < 0)
+    httpserver.afterRequest([] (QHttpServerResponse &&resp) {
+        return std::move(resp);
+    });
+
+#if QT_CONFIG(concurrent)
+    httpserver.route("/future/", [] (int id) -> QHttpServerFutureResponse {
+        if (id == 0)
+            return QHttpServerResponse::StatusCode::NotFound;
+
+        auto future = QtConcurrent::run([] () {
+            QTest::qSleep(500);
+            return QHttpServerResponse("future is coming");
+        });
+
+        return future;
+    });
+#endif
+
+    quint16 port = httpserver.listen();
+    if (!port)
         qCritical() << "Http server listen failed";
 
     urlBase = QStringLiteral("http://localhost:%1%2").arg(port);
@@ -291,7 +325,7 @@ void tst_QHttpServer::initTestCase()
                         QSslKey(g_privateKey, QSsl::Rsa));
 
     port = httpserver.listen();
-    if (port < 0)
+    if (!port)
         qCritical() << "Http server listen failed";
 
     sslUrlBase = QStringLiteral("https://localhost:%1%2").arg(port);
@@ -510,6 +544,20 @@ void tst_QHttpServer::routeGet_data()
         << "text/plain"
         << "part 1 of the message, part 2 of the message";
 
+#if QT_CONFIG(concurrent)
+    QTest::addRow("future")
+        << urlBase.arg("/future/1")
+        << 200
+        << "text/plain"
+        << "future is coming";
+
+    QTest::addRow("future-not-found")
+        << urlBase.arg("/future/0")
+        << 404
+        << "application/x-empty"
+        << "";
+#endif
+
 #if QT_CONFIG(ssl)
 
     QTest::addRow("hello world, ssl")
@@ -655,6 +703,20 @@ void tst_QHttpServer::routePost_data()
         << body
         << body;
 
+    QTest::addRow("req-and-resp")
+        << urlBase.arg("/req-and-resp")
+        << 200
+        << "text/html"
+        << "test"
+        << "test";
+
+    QTest::addRow("resp-and-req")
+        << urlBase.arg("/resp-and-req")
+        << 200
+        << "text/html"
+        << "test"
+        << "test";
+
 #if QT_CONFIG(ssl)
 
     QTest::addRow("post-and-get, post, ssl")
@@ -785,18 +847,21 @@ struct CustomType {
 
 void tst_QHttpServer::invalidRouterArguments()
 {
+    QTest::ignoreMessage(QtWarningMsg, "Can not find converter for type: QDateTime");
     QCOMPARE(
         httpserver.route("/datetime/", [] (const QDateTime &datetime) {
             return QString("datetime: %1").arg(datetime.toString());
         }),
         false);
 
+    QTest::ignoreMessage(QtWarningMsg, "Can not convert GeT to QHttpServerRequest::Method");
     QCOMPARE(
         httpserver.route("/invalid-rule-method", "GeT", [] () {
             return "";
         }),
         false);
 
+    QTest::ignoreMessage(QtWarningMsg, "Can not convert Garbage to QHttpServerRequest::Method");
     QCOMPARE(
         httpserver.route("/invalid-rule-method", "Garbage", [] () {
             return "";
@@ -809,6 +874,9 @@ void tst_QHttpServer::invalidRouterArguments()
         }),
         false);
 
+    QTest::ignoreMessage(QtWarningMsg,
+                         "CustomType has not registered a converter to QString. "
+                         "Use QHttpServerRouter::addConveter<Type>(converter).");
     QCOMPARE(
         httpserver.route("/implicit-conversion-to-qstring-has-no-registered/",
                          [] (const CustomType &) {
@@ -841,6 +909,36 @@ void tst_QHttpServer::checkRouteLambdaCapture()
         return;
 }
 
+void tst_QHttpServer::afterRequest()
+{
+    httpserver.afterRequest([] (QHttpServerResponse &&resp,
+                                const QHttpServerRequest &request) {
+        if (request.url().path() == "/test-after-request")
+            resp.setHeader("Arguments-Order-1", "resp, request");
+
+        return std::move(resp);
+    });
+
+    httpserver.afterRequest([] (const QHttpServerRequest &request,
+                                QHttpServerResponse &&resp) {
+        if (request.url().path() == "/test-after-request")
+            resp.setHeader("Arguments-Order-2", "request, resp");
+
+        return std::move(resp);
+    });
+
+    const QUrl requestUrl(urlBase.arg("/test-after-request"));
+    auto reply = networkAccessManager.get(QNetworkRequest(requestUrl));
+
+    QTRY_VERIFY(reply->isFinished());
+
+    QCOMPARE(reply->header(QNetworkRequest::ContentTypeHeader), "application/x-empty");
+    QCOMPARE(reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt(), 404);
+    QCOMPARE(reply->rawHeader("Arguments-Order-1"), "resp, request");
+    QCOMPARE(reply->rawHeader("Arguments-Order-2"), "request, resp");
+    reply->deleteLater();
+}
+
 void tst_QHttpServer::checkReply(QNetworkReply *reply, const QString &response) {
     QTRY_VERIFY(reply->isFinished());
 
@@ -851,6 +949,24 @@ void tst_QHttpServer::checkReply(QNetworkReply *reply, const QString &response)
     reply->deleteLater();
 };
 
+void tst_QHttpServer::disconnectedInEventLoop()
+{
+    httpserver.route("/event-loop/", [] () {
+        QEventLoop loop;
+        QTimer::singleShot(1000, &loop, &QEventLoop::quit);
+        loop.exec();
+        return QHttpServerResponse::StatusCode::Ok;
+    });
+
+    const QUrl requestUrl(urlBase.arg("/event-loop/"));
+    auto reply = networkAccessManager.get(QNetworkRequest(requestUrl));
+    QTimer::singleShot(500, reply, &QNetworkReply::abort); // cancel connection
+    QEventLoop loop;
+    connect(reply, &QNetworkReply::finished, &loop, &QEventLoop::quit);
+    loop.exec();
+    reply->deleteLater();
+}
+
 QT_END_NAMESPACE
 
 Q_DECLARE_METATYPE(CustomArg);
