@@ -1,7 +1,7 @@
 /*
  * main.cpp - main file for Veyon CLI
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -172,7 +172,7 @@ int main( int argc, char **argv )
 			std::sort( commands.begin(), commands.end() );
 
 			CommandLineIO::print( VeyonCore::tr( "Available commands:" ) );
-			for( const auto& command : qAsConst(commands) )
+			for( const auto& command : std::as_const(commands) )
 			{
 				CommandLineIO::print( QStringLiteral("    %1 - %2").arg( command, it.key()->commandHelp( command ) ) );
 			}
