@@ -1,7 +1,7 @@
 /*
  * MasterConfigurationPage.h - header for the MasterConfigurationPage class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -25,9 +25,6 @@
 #pragma once
 
 #include "ConfigurationPage.h"
-#include "FeatureManager.h"
-
-class BuiltinFeatures;
 
 namespace Ui {
 class MasterConfigurationPage;
@@ -51,12 +48,12 @@ private Q_SLOTS:
 private:
 	void openUserConfigurationDirectory();
 	void openScreenshotDirectory();
+	void openConfigurationTemplatesDirectory();
 	void populateFeatureComboBox();
 	void updateFeatureLists();
 
 	Ui::MasterConfigurationPage *ui;
 
-	FeatureManager m_featureManager;
 	QStringList m_disabledFeatures;
 
 };
