@@ -1,7 +1,7 @@
 /*
  * AccessControlProvider.cpp - implementation of the AccessControlProvider class
  *
- * Copyright (c) 2016-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2016-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -37,18 +37,20 @@
 
 
 AccessControlProvider::AccessControlProvider() :
-	m_accessControlRules(),
-	m_userGroupsBackend( VeyonCore::userGroupsBackendManager().accessControlBackend() ),
-	m_networkObjectDirectory( VeyonCore::networkObjectDirectoryManager().configuredDirectory() ),
-	m_queryDomainGroups( VeyonCore::config().domainGroupsForAccessControlEnabled() )
+	m_userGroupsBackend(VeyonCore::userGroupsBackendManager().configuredBackend()),
+	m_networkObjectDirectory(VeyonCore::networkObjectDirectoryManager().configuredDirectory()),
+	m_useDomainUserGroups(VeyonCore::config().useDomainUserGroups()),
+	m_accessControlFeature(QLatin1String(staticMetaObject.className()),
+						   Feature::Flag::Meta | Feature::Flag::Builtin,
+						   Feature::Uid{QStringLiteral("1815941e-eaef-43ab-b9cd-5403dca3f749")}, {}, {}, {}, {}, {})
 {
 	const QJsonArray accessControlRules = VeyonCore::config().accessControlRules();
 
 	m_accessControlRules.reserve( accessControlRules.size() );
 
-	for( const auto& accessControlRule : accessControlRules )
+	for (const auto& accessControlRule : accessControlRules)
 	{
-		m_accessControlRules.append( AccessControlRule( accessControlRule ) );
+		m_accessControlRules.append(AccessControlRule::Pointer::create(accessControlRule));
 	}
 }
 
@@ -56,7 +58,7 @@ AccessControlProvider::AccessControlProvider() :
 
 QStringList AccessControlProvider::userGroups() const
 {
-	auto userGroupList = m_userGroupsBackend->userGroups( m_queryDomainGroups );
+	auto userGroupList = m_userGroupsBackend->userGroups(m_useDomainUserGroups);
 
 	std::sort( userGroupList.begin(), userGroupList.end() );
 
@@ -118,31 +120,42 @@ QStringList AccessControlProvider::locationsOfComputer( const QString& computer
 
 
 
-AccessControlProvider::Access AccessControlProvider::checkAccess( const QString& accessingUser,
-																  const QString& accessingComputer,
-																  const QStringList& connectedUsers )
+AccessControlProvider::CheckResult AccessControlProvider::checkAccess(const QString& accessingUser,
+																	  const QString& accessingComputer,
+																	  const QStringList& connectedUsers)
 {
-	if( VeyonCore::config().isAccessRestrictedToUserGroups() )
+	CheckResult denyAccessCheckResult{Access::Deny};
+	if (VeyonCore::config().isAccessRestrictedToUserGroups())
 	{
-		if( processAuthorizedGroups( accessingUser ) )
+		if (processAuthorizedGroups(accessingUser))
 		{
-			return Access::Allow;
+			return {Access::Allow, Reason::UserInAuthorizedUserGroups};
 		}
+		denyAccessCheckResult.reason = Reason::UserNotInAuthorizedUserGroups;
 	}
-	else if( VeyonCore::config().isAccessControlRulesProcessingEnabled() )
+	else if (VeyonCore::config().isAccessControlRulesProcessingEnabled())
 	{
-		auto action = processAccessControlRules( accessingUser,
-												 accessingComputer,
-												 VeyonCore::platform().userFunctions().currentUser(),
-												 HostAddress::localFQDN(),
-												 connectedUsers );
-		switch( action )
+		const auto rule = processAccessControlRules(accessingUser,
+													accessingComputer,
+													VeyonCore::platform().userFunctions().currentUser(),
+													HostAddress::localFQDN(),
+													connectedUsers);
+		if (rule)
 		{
-		case AccessControlRule::Action::Allow:
-			return Access::Allow;
-		case AccessControlRule::Action::AskForPermission:
-			return Access::ToBeConfirmed;
-		default: break;
+			switch(rule->action())
+			{
+			case AccessControlRule::Action::Allow:
+				return {Access::Allow, Reason::AccessControlRuleMatched};
+			case AccessControlRule::Action::AskForPermission:
+				return {Access::ToBeConfirmed};
+			default: break;
+			}
+			denyAccessCheckResult.reason = Reason::AccessControlRuleMatched;
+			denyAccessCheckResult.matchedRule = rule;
+		}
+		else
+		{
+			denyAccessCheckResult.reason = Reason::NoAccessControlRuleMatched;
 		}
 	}
 	else
@@ -150,13 +163,13 @@ AccessControlProvider::Access AccessControlProvider::checkAccess( const QString&
 		vDebug() << "no access control method configured, allowing access.";
 
 		// no access control method configured, therefore grant access
-		return Access::Allow;
+		return {Access::Allow};
 	}
 
 	vDebug() << "configured access control method did not succeed, denying access.";
 
 	// configured access control method did not succeed, therefore deny access
-	return Access::Deny;
+	return denyAccessCheckResult;
 }
 
 
@@ -165,52 +178,44 @@ bool AccessControlProvider::processAuthorizedGroups( const QString& accessingUse
 {
 	vDebug() << "processing for user" << accessingUser;
 
-	const auto groupsOfAccessingUser = m_userGroupsBackend->groupsOfUser( accessingUser, m_queryDomainGroups );
+	const auto groupsOfAccessingUser = m_userGroupsBackend->groupsOfUser( accessingUser, m_useDomainUserGroups );
 	const auto authorizedUserGroups = VeyonCore::config().authorizedUserGroups();
 
 	vDebug() << groupsOfAccessingUser << authorizedUserGroups;
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-	const auto groupsOfAccessingUserSet = QSet<QString>{ groupsOfAccessingUser.begin(), groupsOfAccessingUser.end() };
-	const auto authorizedUserGroupSet = QSet<QString>{ authorizedUserGroups.begin(), authorizedUserGroups.end() };
-#else
-	const auto groupsOfAccessingUserSet = groupsOfAccessingUser.toSet();
-	const auto authorizedUserGroupSet = authorizedUserGroups.toSet();
-#endif
-
-	return intersects( groupsOfAccessingUserSet, authorizedUserGroupSet );
+	return qsetFromList(groupsOfAccessingUser).intersects(qsetFromList(authorizedUserGroups));
 }
 
 
 
-AccessControlRule::Action AccessControlProvider::processAccessControlRules( const QString& accessingUser,
+AccessControlRule::Pointer AccessControlProvider::processAccessControlRules(const QString& accessingUser,
 																			const QString& accessingComputer,
 																			const QString& localUser,
 																			const QString& localComputer,
-																			const QStringList& connectedUsers )
+																			const QStringList& connectedUsers)
 {
 	vDebug() << "processing rules for" << accessingUser << accessingComputer << localUser << localComputer << connectedUsers;
 
-	for( const auto& rule : qAsConst( m_accessControlRules ) )
+	for (const auto& rule : std::as_const(m_accessControlRules))
 	{
 		// rule disabled?
-		if( rule.action() == AccessControlRule::Action::None )
+		if (rule->action() == AccessControlRule::Action::None)
 		{
 			// then continue with next rule
 			continue;
 		}
 
-		if( rule.areConditionsIgnored() ||
-			matchConditions( rule, accessingUser, accessingComputer, localUser, localComputer, connectedUsers ) )
+		if (rule->areConditionsIgnored() ||
+			matchConditions(*rule, accessingUser, accessingComputer, localUser, localComputer, connectedUsers))
 		{
-			vDebug() << "rule" << rule.name() << "matched with action" << rule.action();
-			return rule.action();
+			vDebug() << "rule" << rule->name() << "matched with action" << rule->action();
+			return rule;
 		}
 	}
 
 	vDebug() << "no matching rule, denying access";
 
-	return AccessControlRule::Action::Deny;
+	return nullptr;
 }
 
 
@@ -224,12 +229,12 @@ bool AccessControlProvider::isAccessToLocalComputerDenied() const
 		return false;
 	}
 
-	for( const auto& rule : qAsConst( m_accessControlRules ) )
+	for (const auto& rule : std::as_const(m_accessControlRules))
 	{
-		if( matchConditions( rule, {}, {},
-							 VeyonCore::platform().userFunctions().currentUser(), HostAddress::localFQDN(), {} ) )
+		if (matchConditions(*rule, {}, {},
+							VeyonCore::platform().userFunctions().currentUser(), HostAddress::localFQDN(), {}))
 		{
-			switch( rule.action() )
+			switch (rule->action())
 			{
 			case AccessControlRule::Action::Deny:
 				return true;
@@ -247,42 +252,49 @@ bool AccessControlProvider::isAccessToLocalComputerDenied() const
 
 
 
+bool AccessControlProvider::handleFeatureMessage(ComputerControlInterface::Pointer computerControlInterface, const FeatureMessage& message)
+{
+	if (message.featureUid() == m_accessControlFeature.uid())
+	{
+		computerControlInterface->setAccessControlFailed(message.argument(Argument::Details).toString());
+		return true;
+	}
+
+	return false;
+}
+
+
+
+void AccessControlProvider::sendDetails(QIODevice* ioDevice, const QString& details)
+{
+	FeatureMessage{m_accessControlFeature.uid()}.addArgument(
+				AccessControlProvider::Argument::Details, details)
+			.sendAsRfbMessage(ioDevice);
+}
+
+
+
 bool AccessControlProvider::isMemberOfUserGroup( const QString &user,
 												 const QString &groupName ) const
 {
-	const QRegularExpression groupNameRX( groupName );
-
-	if( groupNameRX.isValid() )
-	{
-		return m_userGroupsBackend->groupsOfUser( user, m_queryDomainGroups ).indexOf( groupNameRX ) >= 0;
-	}
-
-	return m_userGroupsBackend->groupsOfUser( user, m_queryDomainGroups ).contains( groupName );
+	return matchList(m_userGroupsBackend->groupsOfUser(user, m_useDomainUserGroups), groupName);
 }
 
 
 
 bool AccessControlProvider::isLocatedAt( const QString &computer, const QString &locationName ) const
 {
-	return locationsOfComputer( computer ).contains( locationName );
+	return matchList(locationsOfComputer(computer), locationName);
 }
 
 
 
 bool AccessControlProvider::haveGroupsInCommon( const QString &userOne, const QString &userTwo ) const
 {
-	const auto userOneGroups = m_userGroupsBackend->groupsOfUser( userOne, m_queryDomainGroups );
-	const auto userTwoGroups = m_userGroupsBackend->groupsOfUser( userTwo, m_queryDomainGroups );
+	const auto userOneGroups = m_userGroupsBackend->groupsOfUser( userOne, m_useDomainUserGroups );
+	const auto userTwoGroups = m_userGroupsBackend->groupsOfUser( userTwo, m_useDomainUserGroups );
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-	const auto userOneGroupSet = QSet<QString>{ userOneGroups.begin(), userOneGroups.end() };
-	const auto userTwoGroupSet = QSet<QString>{ userTwoGroups.begin(), userTwoGroups.end() };
-#else
-	const auto userOneGroupSet = userOneGroups.toSet();
-	const auto userTwoGroupSet = userTwoGroups.toSet();
-#endif
-
-	return intersects( userOneGroupSet, userTwoGroupSet );
+	return qsetFromList(userOneGroups).intersects(qsetFromList(userTwoGroups));
 }
 
 
@@ -444,6 +456,16 @@ bool AccessControlProvider::matchConditions( const AccessControlRule &rule,
 		}
 	}
 
+	if (rule.isConditionEnabled(AccessControlRule::Condition::ComputerAlreadyBeingAccessed))
+	{
+		hasConditions = true;
+
+		if (!connectedUsers.isEmpty() != matchResult)
+		{
+			return false;
+		}
+	}
+
 	// do not match the rule if no conditions are set at all
 	if( hasConditions == false )
 	{
@@ -467,3 +489,25 @@ QStringList AccessControlProvider::objectNames( const NetworkObjectList& objects
 
 	return nameList;
 }
+
+
+
+bool AccessControlProvider::matchList(const QStringList& list, const QString& pattern)
+{
+	if (pattern.startsWith(QLatin1Char('/')) && pattern.endsWith(QLatin1Char('/')) &&
+		pattern.length() > 2)
+	{
+		return list.indexOf(QRegularExpression(pattern.mid(1, pattern.length() - 2))) >= 0;
+	}
+
+	if (pattern.endsWith(QLatin1Char('*')))
+	{
+		const QRegularExpression rx(pattern);
+		if (rx.isValid())
+		{
+			return list.indexOf(rx) >= 0;
+		}
+	}
+
+	return list.contains(pattern);
+}
