@@ -1,7 +1,7 @@
 /*
  * BuiltinFeatures.cpp - implementation of BuiltinFeatures class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,6 +22,7 @@
  *
  */
 
+#include "AccessControlProvider.h"
 #include "BuiltinFeatures.h"
 #include "MonitoringMode.h"
 #include "PluginManager.h"
@@ -32,11 +33,13 @@
 BuiltinFeatures::BuiltinFeatures() :
 	m_systemTrayIcon( new SystemTrayIcon ),
 	m_monitoringMode( new MonitoringMode ),
-	m_desktopAccessDialog( new DesktopAccessDialog )
+	m_desktopAccessDialog( new DesktopAccessDialog ),
+	m_accessControlProvider(new AccessControlProvider)
 {
 	VeyonCore::pluginManager().registerExtraPluginInterface( m_systemTrayIcon );
 	VeyonCore::pluginManager().registerExtraPluginInterface( m_monitoringMode );
 	VeyonCore::pluginManager().registerExtraPluginInterface( m_desktopAccessDialog );
+	VeyonCore::pluginManager().registerExtraPluginInterface(m_accessControlProvider);
 }
 
 
@@ -46,4 +49,5 @@ BuiltinFeatures::~BuiltinFeatures()
 	delete m_systemTrayIcon;
 	delete m_monitoringMode;
 	delete m_desktopAccessDialog;
+	delete m_accessControlProvider;
 }
