@@ -1,7 +1,7 @@
 /*
  * Computer.cpp - represents a computer and provides control methods and data
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -25,13 +25,14 @@
 #include "Computer.h"
 
 Computer::Computer( NetworkObject::Uid networkObjectUid,
-					const QString& name,
+					const QString& displayName,
 					const QString& hostAddress,
 					const QString& macAddress,
 					const QString& location ) :
 	m_networkObjectUid( networkObjectUid ),
-	m_name( name ),
-	m_hostAddress( hostAddress ),
+	m_displayName(displayName),
+	m_hostName(hostAddress),
+	m_hostAddress(hostAddress),
 	m_macAddress( macAddress ),
 	m_location( location )
 {
