@@ -1,7 +1,7 @@
 /*
  * ComputerControlInterface.h - interface class for controlling a computer
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -27,6 +27,7 @@
 #include "Computer.h"
 #include "Feature.h"
 #include "Lockable.h"
+#include "PlatformSessionFunctions.h"
 #include "VeyonCore.h"
 #include "VeyonConnection.h"
 
@@ -38,7 +39,8 @@ public:
 		Disabled,
 		Basic,
 		Monitoring,
-		Live
+		Live,
+		FeatureControlOnly,
 	};
 
 	using Pointer = QSharedPointer<ComputerControlInterface>;
@@ -79,6 +81,13 @@ public:
 		return m_computer;
 	}
 
+	QString computerName() const;
+
+	Computer::NameSource computerNameSource() const
+	{
+		return m_computerNameSource;
+	}
+
 	State state() const
 	{
 		return m_state;
@@ -99,6 +108,13 @@ public:
 
 	QImage framebuffer() const;
 
+	const QString& accessControlDetails() const
+	{
+		return m_accessControlDetails;
+	}
+
+	void setAccessControlFailed(const QString& details);
+
 	VeyonCore::ApplicationVersion serverVersion() const
 	{
 		return m_serverVersion;
@@ -116,12 +132,14 @@ public:
 		return m_userFullName;
 	}
 
-	int userSessionId() const
+	void setUserInformation(const QString& userLoginName, const QString& userFullName);
+
+	const PlatformSessionFunctions::SessionInfo& sessionInfo() const
 	{
-		return m_userSessionId;
+		return m_sessionInfo;
 	}
 
-	void setUserInformation( const QString& userLoginName, const QString& userFullName, int sessionId );
+	void setSessionInfo(const PlatformSessionFunctions::SessionInfo& sessionInfo);
 
 	const ScreenList& screens() const
 	{
@@ -156,11 +174,27 @@ public:
 		return m_updateMode;
 	}
 
+	void setProperty(QUuid propertyId, const QVariant& data);
+
+	QVariant queryProperty(QUuid propertyId);
+
 	Pointer weakPointer();
 
+	template<typename T>
+	void executeIfConnected(const T& functor)
+	{
+		connect(this, &ComputerControlInterface::stateChanged, this, [this, functor]() {
+			if (state() == State::Connected)
+			{
+				functor();
+			}
+		});
+	}
+
 private:
 	void ping();
 	void setMinimumFramebufferUpdateInterval();
+	void setQuality();
 	void resetWatchdog();
 	void restartConnection();
 
@@ -168,6 +202,7 @@ private:
 	void updateServerVersion();
 	void updateActiveFeatures();
 	void updateUser();
+	void updateSessionInfo();
 	void updateScreens();
 
 	void handleFeatureMessage( const FeatureMessage& message );
@@ -181,11 +216,12 @@ private:
 	const int m_port;
 
 	UpdateMode m_updateMode{UpdateMode::Disabled};
+	Computer::NameSource m_computerNameSource{Computer::NameSource::Default};
 
 	State m_state{State::Disconnected};
 	QString m_userLoginName{};
 	QString m_userFullName{};
-	int m_userSessionId{0};
+	PlatformSessionFunctions::SessionInfo m_sessionInfo{};
 	ScreenList m_screens;
 	FeatureUidList m_activeFeatures;
 	Feature::Uid m_designatedModeFeature;
@@ -200,15 +236,21 @@ private:
 	VeyonCore::ApplicationVersion m_serverVersion{VeyonCore::ApplicationVersion::Unknown};
 	QTimer m_serverVersionQueryTimer{this};
 
+	QString m_accessControlDetails{};
 	QTimer m_statePollingTimer{this};
 
+	QMap<QUuid, QVariant> m_properties;
+
 Q_SIGNALS:
+	void accessControlDetailsChanged();
 	void framebufferSizeChanged();
 	void framebufferUpdated();
 	void userChanged();
+	void sessionInfoChanged();
 	void screensChanged();
 	void stateChanged();
 	void activeFeaturesChanged();
+	void propertyChanged(QUuid propertyId);
 
 };
 
