@@ -1,7 +1,7 @@
 /*
  * ConfigurationObject.cpp - implementation of ConfigurationObject
  *
- * Copyright (c) 2009-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2009-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -54,6 +54,10 @@ Configuration::Property::Property( Proxy* proxy, const QString& key, const QStri
 	m_defaultValue( defaultValue ),
 	m_flags( flags )
 {
+	connect (proxy, &QObject::destroyed, this, [this]() {
+		setParent(nullptr);
+		deleteLater();
+	});
 }
 
 
