@@ -1,7 +1,7 @@
 /*
  * DesktopAccessDialog.cpp - implementation of DesktopAccessDialog class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -85,18 +85,15 @@ void DesktopAccessDialog::abort( FeatureWorkerManager* featureWorkerManager )
 
 
 
-bool DesktopAccessDialog::handleFeatureMessage( VeyonServerInterface& server,
-												const MessageContext& messageContext,
-												const FeatureMessage& message )
+bool DesktopAccessDialog::handleFeatureMessageFromWorker(VeyonServerInterface& server,
+														 const FeatureMessage& message)
 {
-	Q_UNUSED(messageContext)
-
 	if( m_desktopAccessDialogFeature.uid() == message.featureUid() &&
 		message.command() == ReportDesktopAccessChoice )
 	{
-		m_choice = QVariantHelper<Choice>::value( message.argument( Argument::Choice ) );
+		m_choice = message.argument(Argument::Choice).value<Choice>();
 
-		server.featureWorkerManager().stopWorker( m_desktopAccessDialogFeature.uid() );
+		server.featureWorkerManager().stopWorker(m_desktopAccessDialogFeature.uid());
 
 		m_abortTimer.stop();
 
