@@ -1,7 +1,7 @@
 /*
  * EnumHelper.h - helper functions for enumerations
  *
- * Copyright (c) 2019-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2019-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -34,7 +34,7 @@ public:
 	template<class T>
 	static QString toString( T item )
 	{
-		return QLatin1String( QMetaEnum::fromType<T>().key( static_cast<int>( item ) ) );
+		return QLatin1String(QMetaEnum::fromType<T>().valueToKey(int(item)));
 	}
 
 	template<class T>
