@@ -1,7 +1,7 @@
 /*
  * FeatureManager.cpp - implementation of the FeatureManager class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -45,7 +45,7 @@ FeatureManager::FeatureManager( QObject* parent ) :
 	qRegisterMetaType<Feature>();
 	qRegisterMetaType<FeatureMessage>();
 
-	for( const auto& pluginObject : qAsConst( VeyonCore::pluginManager().pluginObjects() ) )
+	for( const auto& pluginObject : std::as_const( VeyonCore::pluginManager().pluginObjects() ) )
 	{
 		auto featurePluginInterface = qobject_cast<FeatureProviderInterface *>( pluginObject );
 
@@ -58,6 +58,12 @@ FeatureManager::FeatureManager( QObject* parent ) :
 		}
 	}
 
+	const auto disabledFeatures = VeyonCore::config().disabledFeatures();
+	m_disabledFeaturesUids.reserve(disabledFeatures.count());
+	for (const auto& disabledFeature : disabledFeatures)
+	{
+		m_disabledFeaturesUids.append(Plugin::Uid{disabledFeature});
+	}
 }
 
 
@@ -150,7 +156,7 @@ void FeatureManager::controlFeature( Feature::Uid featureUid,
 									const QVariantMap& arguments,
 									const ComputerControlInterfaceList& computerControlInterfaces ) const
 {
-	for( auto featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( auto featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->controlFeature( featureUid, operation, arguments, computerControlInterfaces );
 	}
@@ -164,7 +170,7 @@ void FeatureManager::startFeature( VeyonMasterInterface& master,
 {
 	vDebug() << computerControlInterfaces << feature.name();
 
-	for( auto featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( auto featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->startFeature( master, feature, computerControlInterfaces );
 	}
@@ -186,7 +192,7 @@ void FeatureManager::stopFeature( VeyonMasterInterface& master,
 {
 	vDebug() << computerControlInterfaces << feature.name();
 
-	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( const auto& featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->stopFeature( master, feature, computerControlInterfaces );
 	}
@@ -207,7 +213,7 @@ void FeatureManager::handleFeatureMessage(ComputerControlInterface::Pointer comp
 {
 	vDebug() << computerControlInterface << message;
 
-	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( const auto& featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->handleFeatureMessage(computerControlInterface, message);
 	}
@@ -221,13 +227,13 @@ void FeatureManager::handleFeatureMessage(VeyonServerInterface& server,
 {
 	vDebug() << "[SERVER]" << message;
 
-	if( VeyonCore::config().disabledFeatures().contains( message.featureUid().toString() ) )
+	if (m_disabledFeaturesUids.contains(message.featureUid()))
 	{
 		vWarning() << "ignoring message as feature" << message.featureUid() << "is disabled by configuration!";
 		return;
 	}
 
-	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( const auto& featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->handleFeatureMessage(server, messageContext, message);
 	}
@@ -235,11 +241,31 @@ void FeatureManager::handleFeatureMessage(VeyonServerInterface& server,
 
 
 
+void FeatureManager::handleFeatureMessageFromWorker(VeyonServerInterface& server,
+													const FeatureMessage& message) const
+{
+	vDebug() << "[FROM WORKER]" << message;
+
+	if (m_disabledFeaturesUids.contains(message.featureUid()))
+	{
+		vWarning() << "ignoring message as feature" << message.featureUid() << "is disabled by configuration!";
+		return;
+	}
+
+	for (const auto& featureInterface : std::as_const(m_featurePluginInterfaces))
+	{
+		featureInterface->handleFeatureMessageFromWorker(server, message);
+	}
+}
+
+
+
+
 void FeatureManager::handleFeatureMessage(VeyonWorkerInterface& worker, const FeatureMessage& message) const
 {
 	vDebug() << "[WORKER]" << message;
 
-	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( const auto& featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		featureInterface->handleFeatureMessage(worker, message);
 	}
@@ -251,7 +277,7 @@ void FeatureManager::sendAsyncFeatureMessages(VeyonServerInterface& server,
 												  const MessageContext& messageContext) const
 {
 
-	for (const auto& featureInterface : qAsConst(m_featurePluginInterfaces))
+	for (const auto& featureInterface : std::as_const(m_featurePluginInterfaces))
 	{
 		featureInterface->sendAsyncFeatureMessages(server, messageContext);
 	}
@@ -263,7 +289,7 @@ FeatureUidList FeatureManager::activeFeatures( VeyonServerInterface& server ) co
 {
 	FeatureUidList features;
 
-	for( const auto& featureInterface : qAsConst( m_featurePluginInterfaces ) )
+	for( const auto& featureInterface : std::as_const( m_featurePluginInterfaces ) )
 	{
 		for( const auto& feature : featureInterface->featureList() )
 		{
