@@ -1,7 +1,7 @@
 /*
  * FeatureMessage.cpp - implementation of a message encapsulation class for features
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -27,11 +27,11 @@
 #include "VariantArrayMessage.h"
 
 
-bool FeatureMessage::send( QIODevice* ioDevice ) const
+bool FeatureMessage::sendPlain(QIODevice* ioDevice) const
 {
-	if( ioDevice )
+	if (ioDevice)
 	{
-		VariantArrayMessage message( ioDevice );
+		VariantArrayMessage message(ioDevice);
 
 		message.write( m_featureUid );
 		message.write( m_command );
@@ -47,6 +47,23 @@ bool FeatureMessage::send( QIODevice* ioDevice ) const
 
 
 
+bool FeatureMessage::sendAsRfbMessage(QIODevice* ioDevice) const
+{
+	if (ioDevice)
+	{
+		const char rfbMessageType = FeatureMessage::RfbMessageType;
+		ioDevice->write(&rfbMessageType, sizeof(rfbMessageType));
+
+		return sendPlain(ioDevice);
+	}
+
+	vCritical() << "no IO device!";
+
+	return false;
+}
+
+
+
 bool FeatureMessage::isReadyForReceive( QIODevice* ioDevice )
 {
 	return ioDevice != nullptr &&
@@ -64,7 +81,7 @@ bool FeatureMessage::receive( QIODevice* ioDevice )
 		if( message.receive() )
 		{
 			m_featureUid = message.read().toUuid(); // Flawfinder: ignore
-			m_command = QVariantHelper<Command>::value( message.read() ); // Flawfinder: ignore
+			m_command = message.read().value<Command>(); // Flawfinder: ignore
 			m_arguments = message.read().toMap(); // Flawfinder: ignore
 			return true;
 		}
