@@ -1,7 +1,7 @@
 /*
  * FeatureWorkerManager.cpp - class for managing feature worker instances
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -271,7 +271,7 @@ void FeatureWorkerManager::processConnection( QTcpSocket* socket )
 
 		if( message.command() >= 0 )
 		{
-			VeyonCore::featureManager().handleFeatureMessage( m_server, MessageContext( socket ), message );
+			VeyonCore::featureManager().handleFeatureMessageFromWorker(m_server, message);
 		}
 	}
 	else
@@ -336,7 +336,7 @@ void FeatureWorkerManager::sendPendingMessages()
 
 		while( worker.socket && worker.pendingMessages.isEmpty() == false )
 		{
-			worker.pendingMessages.first().send( worker.socket );
+			worker.pendingMessages.first().sendPlain(worker.socket);
 			worker.pendingMessages.removeFirst();
 		}
 	}
