@@ -1,7 +1,7 @@
 /*
  * FileSystemBrowser.cpp - a wrapper class for easily browsing the file system
  *
- * Copyright (c) 2010-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2010-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -66,18 +66,16 @@ QString FileSystemBrowser::exec( const QString &path,
 	switch( m_browseMode )
 	{
 		case ExistingDirectory:
-			chosenPath = QFileDialog::getExistingDirectory( nullptr, title,
+			chosenPath = QFileDialog::getExistingDirectory(m_parent, title,
 								browsePath,
 								QFileDialog::ShowDirsOnly |
 									QFileDialog::DontResolveSymlinks );
 			break;
 		case ExistingFile:
-			chosenPath = QFileDialog::getOpenFileName( nullptr, title,
-														browsePath, filter );
+			chosenPath = QFileDialog::getOpenFileName(m_parent, title, browsePath, filter);
 			break;
 		case SaveFile:
-			chosenPath = QFileDialog::getSaveFileName( nullptr, title,
-														browsePath, filter );
+			chosenPath = QFileDialog::getSaveFileName(m_parent, title, browsePath, filter);
 			break;
 
 		default: break;
