@@ -1,7 +1,7 @@
 /*
  * Filesystem.cpp - filesystem related query and manipulation functions
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -30,6 +30,7 @@
 #include "VeyonConfiguration.h"
 #include "Filesystem.h"
 #include "PlatformFilesystemFunctions.h"
+#include "PlatformUserFunctions.h"
 
 
 QString Filesystem::expandPath( QString path ) const
@@ -40,6 +41,7 @@ QString Filesystem::expandPath( QString path ) const
 											 replace( QStringLiteral( "$HOSTNAME" ), QHostInfo::localHostName() ).
 											 replace( QStringLiteral( "%PROFILE%" ), QDir::homePath() ).
 											 replace( QStringLiteral( "$PROFILE" ), QDir::homePath() ).
+											 replace(QStringLiteral( "%USER%" ), VeyonCore::platform().userFunctions().currentUser()).
 											 replace(QStringLiteral("%DESKTOP%"), QStandardPaths::writableLocation(QStandardPaths::DesktopLocation)).
 											 replace(QStringLiteral("%DOCUMENTS%"), QStandardPaths::writableLocation(QStandardPaths::DocumentsLocation)).
 											 replace(QStringLiteral("%DOWNLOADS%"), QStandardPaths::writableLocation(QStandardPaths::DownloadLocation)).
