@@ -1,7 +1,7 @@
 /*
  *  LockWidget.cpp - widget for locking a client
  *
- *  Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
+ *  Copyright (c) 2006-2025 Tobias Junghans <tobydox@veyon.io>
  *
  *  This file is part of Veyon - https://veyon.io
  *
@@ -58,12 +58,20 @@ LockWidget::LockWidget( Mode mode, const QPixmap& background, QWidget* parent )
 
 	setWindowTitle( {} );
 
+#ifdef Q_OS_LINUX
+	show();
+#endif
 	move(leftMostScreen->geometry().topLeft());
+#ifndef Q_OS_LINUX
 	showFullScreen();
+#endif
 	windowHandle()->setScreen(leftMostScreen);
 	setFixedSize(leftMostScreen->virtualSize());
 
 	VeyonCore::platform().coreFunctions().raiseWindow(this, true);
+#ifdef Q_OS_LINUX
+	showFullScreen();
+#endif
 
 	setFocusPolicy( Qt::StrongFocus );
 	setFocus();
