@@ -1,7 +1,7 @@
 /*
  * MonitoringMode.cpp - implementation of MonitoringMode class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,7 +28,6 @@
 
 #include "FeatureManager.h"
 #include "MonitoringMode.h"
-#include "PlatformSessionFunctions.h"
 #include "PlatformUserFunctions.h"
 #include "VeyonConfiguration.h"
 #include "VeyonServerInterface.h"
@@ -51,23 +50,34 @@ MonitoringMode::MonitoringMode( QObject* parent ) :
 						   Feature::Flag::Service | Feature::Flag::Builtin,
 						   Feature::Uid{"a0a96fba-425d-414a-aaf4-352b76d7c4f3"}, {},
 						   tr("Query active features"), {}, {} ),
-	m_queryLoggedOnUserInfoFeature( QStringLiteral("UserSessionInfo"),
-									Feature::Flag::Session | Feature::Flag::Service | Feature::Flag::Builtin,
-									Feature::Uid( "79a5e74d-50bd-4aab-8012-0e70dc08cc72" ),
-									Feature::Uid(), {}, {}, {} ),
+	m_queryUserInfoFeature(QStringLiteral("UserInfo"),
+						   Feature::Flag::Session | Feature::Flag::Service | Feature::Flag::Builtin,
+						   Feature::Uid("79a5e74d-50bd-4aab-8012-0e70dc08cc72"),
+						   Feature::Uid(), {}, {}, {} ),
+	m_querySessionInfoFeature(QStringLiteral("SessionInfo"),
+							  Feature::Flag::Session | Feature::Flag::Service | Feature::Flag::Builtin,
+							  Feature::Uid("699ed9dd-f58b-477b-a0af-df8105571b3c"),
+							  Feature::Uid(), {}, {}, {}),
 	m_queryScreensFeature( QStringLiteral("QueryScreens"),
 						   Feature::Flag::Meta,
 						   Feature::Uid("d5bbc486-7bc5-4c36-a9a8-1566c8b0091a"),
 						   Feature::Uid(), tr("Query properties of remotely available screens"), {}, {} ),
 	m_features({ m_monitoringModeFeature, m_queryApplicationVersionFeature, m_queryActiveFeatures,
-				  m_queryLoggedOnUserInfoFeature, m_queryScreensFeature })
+			   m_queryUserInfoFeature, m_querySessionInfoFeature, m_queryScreensFeature}),
+	m_sessionMetaDataContent(VeyonCore::config().sessionMetaDataContent()),
+	m_sessionMetaDataEnvironmentVariable(VeyonCore::config().sessionMetaDataEnvironmentVariable()),
+	m_sessionMetaDataRegistryKey(VeyonCore::config().sessionMetaDataRegistryKey())
 {
 	if(VeyonCore::component() == VeyonCore::Component::Server)
 	{
 		connect(&m_activeFeaturesUpdateTimer, &QTimer::timeout, this, &MonitoringMode::updateActiveFeatures);
 		m_activeFeaturesUpdateTimer.start(ActiveFeaturesUpdateInterval);
 
-		updateUserData();
+		connect(&m_sessionInfoUpdateTimer, &QTimer::timeout, this, &MonitoringMode::updateSessionInfo);
+		m_sessionInfoUpdateTimer.start(SessionInfoUpdateInterval);
+
+		updateUserInfo();
+		updateSessionInfo();
 		updateScreenInfoList();
 
 		connect(qGuiApp, &QGuiApplication::screenAdded, this, &MonitoringMode::updateScreenInfoList);
@@ -88,8 +98,8 @@ void MonitoringMode::setMinimumFramebufferUpdateInterval(const ComputerControlIn
 														 int interval)
 {
 	sendFeatureMessage(FeatureMessage{m_monitoringModeFeature.uid(), Command::SetMinimumFramebufferUpdateInterval}
-							.addArgument(Argument::MinimumFramebufferUpdateInterval, interval),
-						computerControlInterfaces);
+					   .addArgument(Argument::MinimumFramebufferUpdateInterval, interval),
+					   computerControlInterfaces);
 }
 
 
@@ -108,9 +118,16 @@ void MonitoringMode::queryActiveFeatures(const ComputerControlInterfaceList& com
 
 
 
-void MonitoringMode::queryLoggedOnUserInfo( const ComputerControlInterfaceList& computerControlInterfaces )
+void MonitoringMode::queryUserInfo(const ComputerControlInterfaceList& computerControlInterfaces)
 {
-	sendFeatureMessage(FeatureMessage{m_queryLoggedOnUserInfoFeature.uid()}, computerControlInterfaces);
+	sendFeatureMessage(FeatureMessage{m_queryUserInfoFeature.uid()}, computerControlInterfaces);
+}
+
+
+
+void MonitoringMode::querySessionInfo(const ComputerControlInterfaceList& computerControlInterfaces)
+{
+	sendFeatureMessage(FeatureMessage{m_querySessionInfoFeature.uid()}, computerControlInterfaces);
 }
 
 
@@ -123,7 +140,7 @@ void MonitoringMode::queryScreens(const ComputerControlInterfaceList& computerCo
 
 
 bool MonitoringMode::handleFeatureMessage( ComputerControlInterface::Pointer computerControlInterface,
-										  const FeatureMessage& message )
+										   const FeatureMessage& message )
 {
 	if (message.featureUid() == m_monitoringModeFeature.uid())
 	{
@@ -137,7 +154,7 @@ bool MonitoringMode::handleFeatureMessage( ComputerControlInterface::Pointer com
 	if (message.featureUid() == m_queryApplicationVersionFeature.uid())
 	{
 		computerControlInterface->setServerVersion(message.argument(Argument::ApplicationVersion)
-														.value<VeyonCore::ApplicationVersion>());
+												   .value<VeyonCore::ApplicationVersion>());
 		return true;
 	}
 
@@ -158,11 +175,24 @@ bool MonitoringMode::handleFeatureMessage( ComputerControlInterface::Pointer com
 		return true;
 	}
 
-	if( message.featureUid() == m_queryLoggedOnUserInfoFeature.uid() )
+	if( message.featureUid() == m_queryUserInfoFeature.uid() )
 	{
-		computerControlInterface->setUserInformation( message.argument( Argument::UserLoginName ).toString(),
-													  message.argument( Argument::UserFullName ).toString(),
-													  message.argument( Argument::UserSessionId ).toInt() );
+		computerControlInterface->setUserInformation(message.argument( Argument::UserLoginName ).toString(),
+													 message.argument( Argument::UserFullName ).toString());
+
+		return true;
+	}
+
+	if (message.featureUid() == m_querySessionInfoFeature.uid())
+	{
+		computerControlInterface->setSessionInfo(PlatformSessionFunctions::SessionInfo{
+													 message.argument(Argument::SessionId).toInt(),
+													 message.argument(Argument::SessionUptime).toInt(),
+													 message.argument(Argument::SessionClientAddress).toString(),
+													 message.argument(Argument::SessionClientName).toString(),
+													 message.argument(Argument::SessionHostName).toString(),
+													 message.argument(Argument::SessionMetaData).toString(),
+												 });
 
 		return true;
 	}
@@ -192,9 +222,9 @@ bool MonitoringMode::handleFeatureMessage( ComputerControlInterface::Pointer com
 
 
 
-bool MonitoringMode::handleFeatureMessage( VeyonServerInterface& server,
+bool MonitoringMode::handleFeatureMessage(VeyonServerInterface& server,
 										  const MessageContext& messageContext,
-										  const FeatureMessage& message )
+										  const FeatureMessage& message)
 {
 	if (message.featureUid() == m_monitoringModeFeature.uid())
 	{
@@ -206,7 +236,7 @@ bool MonitoringMode::handleFeatureMessage( VeyonServerInterface& server,
 		if (message.command() == Command::SetMinimumFramebufferUpdateInterval)
 		{
 			server.setMinimumFramebufferUpdateInterval(messageContext,
-														message.argument(Argument::MinimumFramebufferUpdateInterval).toInt());
+													   message.argument(Argument::MinimumFramebufferUpdateInterval).toInt());
 			return true;
 		}
 	}
@@ -214,8 +244,8 @@ bool MonitoringMode::handleFeatureMessage( VeyonServerInterface& server,
 	if (message.featureUid() == m_queryApplicationVersionFeature.uid())
 	{
 		server.sendFeatureMessageReply(messageContext,
-										FeatureMessage{m_queryApplicationVersionFeature.uid()}
-											.addArgument(Argument::ApplicationVersion, int(VeyonCore::config().applicationVersion())));
+									   FeatureMessage{m_queryApplicationVersionFeature.uid()}
+									   .addArgument(Argument::ApplicationVersion, int(VeyonCore::config().applicationVersion())));
 	}
 
 	if (m_queryActiveFeatures.uid() == message.featureUid())
@@ -223,11 +253,16 @@ bool MonitoringMode::handleFeatureMessage( VeyonServerInterface& server,
 		return sendActiveFeatures(server, messageContext);
 	}
 
-	if (message.featureUid() == m_queryLoggedOnUserInfoFeature.uid())
+	if (message.featureUid() == m_queryUserInfoFeature.uid())
 	{
 		return sendUserInformation(server, messageContext);
 	}
 
+	if (message.featureUid() == m_querySessionInfoFeature.uid())
+	{
+		return sendSessionInfo(server, messageContext);
+	}
+
 	if (message.featureUid() == m_queryScreensFeature.uid())
 	{
 		return sendScreenInfoList(server, messageContext);
@@ -251,15 +286,24 @@ void MonitoringMode::sendAsyncFeatureMessages(VeyonServerInterface& server, cons
 	const auto currentUserInfoVersion = m_userInfoVersion.loadAcquire();
 	const auto contextUserInfoVersion = messageContext.ioDevice()->property(userInfoVersionProperty()).toInt();
 
-	if(contextUserInfoVersion  != currentUserInfoVersion)
+	if(contextUserInfoVersion != currentUserInfoVersion)
 	{
 		sendUserInformation(server, messageContext);
 		messageContext.ioDevice()->setProperty(userInfoVersionProperty(), currentUserInfoVersion);
 	}
 
+	const auto currentSessionInfoVersion = m_sessionInfoVersion.loadAcquire();
+	const auto sessionInfoVersion = messageContext.ioDevice()->property(sessionInfoVersionProperty()).toInt();
+
+	if (sessionInfoVersion != currentSessionInfoVersion)
+	{
+		sendSessionInfo(server, messageContext);
+		messageContext.ioDevice()->setProperty(sessionInfoVersionProperty(), currentSessionInfoVersion);
+	}
+
 	const auto screenInfoVersion = messageContext.ioDevice()->property(screenInfoListVersionProperty()).toInt();
 
-	if (screenInfoVersion  != m_screenInfoListVersion)
+	if (screenInfoVersion != m_screenInfoListVersion)
 	{
 		sendScreenInfoList(server, messageContext);
 		messageContext.ioDevice()->setProperty(screenInfoListVersionProperty(), m_screenInfoListVersion);
@@ -271,29 +315,27 @@ void MonitoringMode::sendAsyncFeatureMessages(VeyonServerInterface& server, cons
 bool MonitoringMode::sendActiveFeatures(VeyonServerInterface& server, const MessageContext& messageContext)
 {
 	return server.sendFeatureMessageReply(messageContext,
-										   FeatureMessage{m_queryActiveFeatures.uid()}
-											   .addArgument(Argument::ActiveFeaturesList, m_activeFeatures));
+										  FeatureMessage{m_queryActiveFeatures.uid()}
+										  .addArgument(Argument::ActiveFeaturesList, m_activeFeatures));
 }
 
 
 
 bool MonitoringMode::sendUserInformation(VeyonServerInterface& server, const MessageContext& messageContext)
 {
-	FeatureMessage message{m_queryLoggedOnUserInfoFeature.uid()};
+	FeatureMessage message{m_queryUserInfoFeature.uid()};
 
 	m_userDataLock.lockForRead();
 	if (m_userLoginName.isEmpty())
 	{
-		updateUserData();
+		updateUserInfo();
 		message.addArgument(Argument::UserLoginName, QString{});
 		message.addArgument(Argument::UserFullName, QString{});
-		message.addArgument(Argument::UserSessionId, -1);
 	}
 	else
 	{
 		message.addArgument(Argument::UserLoginName, m_userLoginName);
 		message.addArgument(Argument::UserFullName, m_userFullName);
-		message.addArgument(Argument::UserSessionId, m_userSessionId);
 	}
 	m_userDataLock.unlock();
 
@@ -302,11 +344,29 @@ bool MonitoringMode::sendUserInformation(VeyonServerInterface& server, const Mes
 
 
 
+bool MonitoringMode::sendSessionInfo(VeyonServerInterface& server, const MessageContext& messageContext)
+{
+	FeatureMessage message{m_querySessionInfoFeature.uid()};
+
+	m_sessionInfoLock.lockForRead();
+	message.addArgument(Argument::SessionId, m_sessionInfo.id);
+	message.addArgument(Argument::SessionUptime, m_sessionInfo.uptime);
+	message.addArgument(Argument::SessionClientAddress, m_sessionInfo.clientAddress);
+	message.addArgument(Argument::SessionClientName, m_sessionInfo.clientName);
+	message.addArgument(Argument::SessionHostName, m_sessionInfo.hostName);
+	message.addArgument(Argument::SessionMetaData, m_sessionInfo.metaData);
+	m_sessionInfoLock.unlock();
+
+	return server.sendFeatureMessageReply(messageContext,message);
+}
+
+
+
 bool MonitoringMode::sendScreenInfoList(VeyonServerInterface& server, const MessageContext& messageContext)
 {
 	return server.sendFeatureMessageReply(messageContext,
-										   FeatureMessage{m_queryScreensFeature.uid()}
-											   .addArgument(Argument::ScreenInfoList, m_screenInfoList));
+										  FeatureMessage{m_queryScreensFeature.uid()}
+										  .addArgument(Argument::ScreenInfoList, m_screenInfoList));
 }
 
 
@@ -336,7 +396,7 @@ void MonitoringMode::updateActiveFeatures()
 
 
 
-void MonitoringMode::updateUserData()
+void MonitoringMode::updateUserInfo()
 {
 	// asynchronously query information about logged on user (which might block
 	// due to domain controller queries and timeouts etc.)
@@ -345,24 +405,66 @@ void MonitoringMode::updateUserData()
 		{
 			const auto userLoginName = VeyonCore::platform().userFunctions().currentUser();
 			const auto userFullName = VeyonCore::platform().userFunctions().fullName( userLoginName );
-			const auto userSessionId = VeyonCore::sessionId();
 			m_userDataLock.lockForWrite();
 			if(m_userLoginName != userLoginName ||
-				m_userFullName != userFullName ||
-				m_userSessionId != userSessionId )
+			   m_userFullName != userFullName)
 			{
 				m_userLoginName = userLoginName;
 				m_userFullName = userFullName;
-				m_userSessionId = userSessionId;
 				++m_userInfoVersion;
 			}
 			m_userDataLock.unlock();
 		}
+
+		m_userDataLock.lockForRead();
+		if (m_userLoginName.isEmpty() && m_userFullName.isEmpty())
+		{
+			QTimer::singleShot(UserInfoUpdateRetryInterval, this, &MonitoringMode::updateUserInfo);
+		}
+		m_userDataLock.unlock();
 	} );
 }
 
 
 
+void MonitoringMode::updateSessionInfo()
+{
+	(void) QtConcurrent::run([=]() {
+		QString sessionMetaData;
+		switch (m_sessionMetaDataContent)
+		{
+		case PlatformSessionFunctions::SessionMetaDataContent::EnvironmentVariable:
+			sessionMetaData = VeyonCore::platform().sessionFunctions().currentSessionEnvironmentVariables().value(m_sessionMetaDataEnvironmentVariable);
+			break;
+		case PlatformSessionFunctions::SessionMetaDataContent::RegistryKey:
+			sessionMetaData = VeyonCore::platform().sessionFunctions().querySettingsValueInCurrentSession(m_sessionMetaDataRegistryKey).toString();
+			break;
+		case PlatformSessionFunctions::SessionMetaDataContent::None:
+			break;
+		}
+
+		const PlatformSessionFunctions::SessionInfo currentSessionInfo{
+			VeyonCore::sessionId(),
+					VeyonCore::platform().sessionFunctions().currentSessionUptime(),
+					VeyonCore::platform().sessionFunctions().currentSessionClientAddress(),
+					VeyonCore::platform().sessionFunctions().currentSessionClientName(),
+					VeyonCore::platform().sessionFunctions().currentSessionHostName(),
+					sessionMetaData
+		};
+
+		m_sessionInfoLock.lockForWrite();
+		if (currentSessionInfo != m_sessionInfo)
+		{
+			m_sessionInfo = currentSessionInfo;
+			++m_sessionInfoVersion;
+		}
+		m_sessionInfoLock.unlock();
+	});
+}
+
+
+
+
 void MonitoringMode::updateScreenInfoList()
 {
 	const auto screens = QGuiApplication::screens();
