@@ -1,7 +1,7 @@
 /*
  * NetworkObject.cpp - data class representing a network object
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -85,6 +85,11 @@ NetworkObject::NetworkObject( const QJsonObject& jsonObject ) :
 
 NetworkObject& NetworkObject::operator=( const NetworkObject& other )
 {
+	if( this == &other )
+	{
+		return *this;
+	}
+
 	m_type = other.type();
 	m_name = other.name();
 	m_hostAddress = other.hostAddress();
