@@ -24,6 +24,8 @@
 
 #pragma once
 
+#include <QNetworkInterface>
+
 #include "PlatformPluginInterface.h"
 
 // clazy:excludeall=copyable-polymorphic
@@ -50,4 +52,7 @@ public:
 
 	virtual bool configureSocketKeepalive( Socket socket, bool enabled, int idleTime, int interval, int probes ) = 0;
 
+	virtual QNetworkInterface defaultRouteNetworkInterface() = 0;
+	virtual int networkInterfaceSpeedInMBitPerSecond(const QNetworkInterface& networkInterface) = 0;
+
 };
