@@ -2,7 +2,7 @@
  * VeyonConfiguration.cpp - a Configuration object storing system wide
  *                          configuration values
  *
- * Copyright (c) 2010-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2010-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -32,8 +32,8 @@
 
 
 VeyonConfiguration::VeyonConfiguration() :
-	Configuration::Object( Configuration::Store::LocalBackend,
-						   Configuration::Store::System )
+	Configuration::Object(Configuration::Store::Backend::Local,
+						  Configuration::Store::Scope::System)
 {
 }
 
@@ -72,4 +72,14 @@ void VeyonConfiguration::upgrade()
 	{
 		setApplicationVersion(VeyonCore::ApplicationVersion::Version_4_7);
 	}
+	else if (applicationVersion() < VeyonCore::ApplicationVersion::Version_4_8)
+	{
+		setApplicationVersion(VeyonCore::ApplicationVersion::Version_4_8);
+	}
+	else if (applicationVersion() < VeyonCore::ApplicationVersion::Version_4_9)
+	{
+		setUserGroupsBackend(legacyAccessControlUserGroupsBackend());
+		setUseDomainUserGroups(legacyDomainGroupsForAccessControlEnabled());
+		setApplicationVersion(VeyonCore::ApplicationVersion::Version_4_9);
+	}
 }
