@@ -1,7 +1,7 @@
 /*
  * VeyonCore.cpp - implementation of Veyon Core
  *
- * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -34,7 +34,10 @@
 #include <QLibraryInfo>
 #include <QProcessEnvironment>
 #include <QRegularExpression>
+#include <QStyleFactory>
+#include <QStyleHints>
 #include <QSysInfo>
+#include <QToolTip>
 
 #include "BuiltinFeatures.h"
 #include "FeatureManager.h"
@@ -87,6 +90,8 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 
 	initLocaleAndTranslation();
 
+	initUi();
+
 	initCryptoCore();
 
 	initAuthenticationCredentials();
@@ -95,6 +100,8 @@ VeyonCore::VeyonCore( QCoreApplication* application, Component component, const
 
 	initManagers();
 
+	initFeatures();
+
 	initSystemInfo();
 
 	Q_EMIT initialized(); // clazy:exclude=incorrect-emit
@@ -109,15 +116,15 @@ VeyonCore::~VeyonCore()
 	delete m_featureManager;
 	m_featureManager = nullptr;
 
+	delete m_builtinFeatures;
+	m_builtinFeatures = nullptr;
+
 	delete m_userGroupsBackendManager;
 	m_userGroupsBackendManager = nullptr;
 
 	delete m_authenticationCredentials;
 	m_authenticationCredentials = nullptr;
 
-	delete m_builtinFeatures;
-	m_builtinFeatures = nullptr;
-
 	delete m_logger;
 	m_logger = nullptr;
 
@@ -171,7 +178,11 @@ QString VeyonCore::translationsDirectory()
 
 QString VeyonCore::qtTranslationsDirectory()
 {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	const auto path = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+#else
 	const auto path = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+#endif
 	if( QDir{path}.exists() )
 	{
 		return path;
@@ -277,6 +288,29 @@ void VeyonCore::enforceBranding( QWidget *topLevelWidget )
 
 
 
+bool VeyonCore::useDarkMode()
+{
+	const auto colorScheme = config().uiColorScheme();
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	if (colorScheme == UiColorScheme::System &&
+		QGuiApplication::styleHints() &&
+		QGuiApplication::styleHints()->colorScheme() == Qt::ColorScheme::Dark)
+	{
+		return true;
+	}
+#endif
+
+	if (colorScheme == UiColorScheme::Dark)
+	{
+		return true;
+	}
+
+	return false;
+}
+
+
+
 bool VeyonCore::isDebugging()
 {
 	return s_instance && s_instance->m_debugging;
@@ -504,7 +538,8 @@ QString VeyonCore::screenName(const QScreen& screen, int index)
 
 bool VeyonCore::isAuthenticationKeyNameValid( const QString& authKeyName )
 {
-	return QRegularExpression( QStringLiteral("^[\\w-]+$") ).match( authKeyName ).hasMatch();
+	static const QRegularExpression keyNameRX{QStringLiteral("^[\\w-]+$")};
+	return keyNameRX.match( authKeyName ).hasMatch();
 }
 
 
@@ -519,6 +554,8 @@ int VeyonCore::exec()
 
 	vDebug() << "Exit";
 
+	Q_EMIT exited();
+
 	return result;
 }
 
@@ -618,6 +655,46 @@ void VeyonCore::initLocaleAndTranslation()
 
 
 
+void VeyonCore::initUi()
+{
+	auto app = qobject_cast<QApplication *>(QCoreApplication::instance());
+	if (app)
+	{
+		if (m_config->uiStyle() == UiStyle::Fusion)
+		{
+			app->setStyle(QStyleFactory::create(QStringLiteral("Fusion")));
+		}
+
+		app->setStyleSheet(QStringLiteral(
+							   "QToolButton:checked {background-color:#88ddff;}"
+							   "QToolTip {padding:5px; border:0px;}"
+							   ));
+
+		auto toolTipPalette = QToolTip::palette();
+		static const char* toolTipBackgroundColor = "#198cb3";
+		toolTipPalette.setColor(QPalette::Window, toolTipBackgroundColor);
+		toolTipPalette.setColor(QPalette::ToolTipBase, toolTipBackgroundColor);
+		toolTipPalette.setColor(QPalette::ToolTipText, Qt::white);
+		QToolTip::setPalette(toolTipPalette);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 8, 0)
+		switch (config().uiColorScheme())
+		{
+		case UiColorScheme::Dark:
+			QGuiApplication::styleHints()->setColorScheme(Qt::ColorScheme::Dark);
+			break;
+		case UiColorScheme::Light:
+			QGuiApplication::styleHints()->setColorScheme(Qt::ColorScheme::Light);
+			break;
+		default:
+			break;
+		}
+#endif
+	}
+}
+
+
+
 void VeyonCore::initCryptoCore()
 {
 	m_cryptoCore = new CryptoCore;
@@ -643,21 +720,26 @@ void VeyonCore::initPlugins()
 	// load all other (non-platform) plugins
 	m_pluginManager->loadPlugins();
 	m_pluginManager->upgradePlugins();
-
-	m_builtinFeatures = new BuiltinFeatures();
 }
 
 
 
 void VeyonCore::initManagers()
 {
-	m_featureManager = new FeatureManager(this);
 	m_userGroupsBackendManager = new UserGroupsBackendManager( this );
 	m_networkObjectDirectoryManager = new NetworkObjectDirectoryManager( this );
 }
 
 
 
+void VeyonCore::initFeatures()
+{
+	m_builtinFeatures = new BuiltinFeatures();
+	m_featureManager = new FeatureManager(this);
+}
+
+
+
 bool VeyonCore::initLogonAuthentication()
 {
 	if( qobject_cast<QApplication *>( QCoreApplication::instance() ) )
