@@ -1,7 +1,7 @@
 /*
  * VncClientProtocol.h - header file for the VncClientProtocol class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -74,8 +74,11 @@ public:
 		return m_framebufferHeight;
 	}
 
-	bool setPixelFormat( rfbPixelFormat pixelFormat );
-	bool setEncodings( const QVector<uint32_t>& encodings );
+	void setPixelFormat(rfbPixelFormat pixelFormat);
+	void setEncodings(const QVector<uint32_t>& encodings);
+
+	bool sendPixelFormat();
+	bool sendEncodings();
 
 	void requestFramebufferUpdate( bool incremental );
 
@@ -128,6 +131,8 @@ private:
 									uint bytesPerPixel );
 	bool handleRectEncodingZlib( QBuffer& buffer );
 	bool handleRectEncodingZRLE( QBuffer& buffer );
+	bool handleRectEncodingTight(QBuffer& buffer,
+								 const rfbFramebufferUpdateRectHeader rectHeader);
 	bool handleRectEncodingExtDesktopSize(QBuffer& buffer);
 
 	static bool isPseudoEncoding( rfbFramebufferUpdateRectHeader header );
@@ -141,7 +146,8 @@ private:
 
 	QByteArray m_serverInitMessage;
 
-	rfbPixelFormat m_pixelFormat;
+	rfbPixelFormat m_pixelFormat{};
+	QVector<uint32_t> m_encodings{};
 
 	quint16 m_framebufferWidth;
 	quint16 m_framebufferHeight;
