@@ -1,7 +1,7 @@
 /*
  * VncConnection.cpp - implementation of VncConnection class
  *
- * Copyright (c) 2008-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2008-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -169,7 +169,6 @@ VncConnection::VncConnection( QObject* parent ) :
 	m_framebufferState( FramebufferState::Invalid ),
 	m_controlFlags(),
 	m_client( nullptr ),
-	m_quality( Quality::Default ),
 	m_host(),
 	m_port( -1 ),
 	m_defaultPort( VeyonCore::config().veyonServerPort() ),
@@ -186,7 +185,8 @@ VncConnection::VncConnection( QObject* parent ) :
 		m_connectionRetryInterval = VeyonCore::config().vncConnectionRetryInterval();
 		m_messageWaitTimeout = VeyonCore::config().vncConnectionMessageWaitTimeout();
 		m_fastFramebufferUpdateInterval = VeyonCore::config().vncConnectionFastFramebufferUpdateInterval();
-		m_framebufferUpdateWatchdogTimeout = VeyonCore::config().vncConnectionFramebufferUpdateWatchdogTimeout();
+		m_initialFramebufferUpdateTimeout = VeyonCore::config().vncConnectionInitialFramebufferUpdateTimeout();
+		m_framebufferUpdateTimeout = VeyonCore::config().vncConnectionFramebufferUpdateTimeout();
 		m_socketKeepaliveIdleTime = VeyonCore::config().vncConnectionSocketKeepaliveIdleTime();
 		m_socketKeepaliveInterval = VeyonCore::config().vncConnectionSocketKeepaliveInterval();
 		m_socketKeepaliveCount = VeyonCore::config().vncConnectionSocketKeepaliveCount();
@@ -240,7 +240,15 @@ QImage VncConnection::image()
 
 void VncConnection::restart()
 {
-	setControlFlag( ControlFlag::RestartConnection, true );
+	if (isRunning())
+	{
+		setControlFlag(ControlFlag::RestartConnection, true);
+	}
+	else
+	{
+		setControlFlag(ControlFlag::TerminateThread, false);
+		start();
+	}
 }
 
 
@@ -278,18 +286,25 @@ void VncConnection::setHost( const QString& host )
 	QMutexLocker locker( &m_globalMutex );
 	m_host = host;
 
+	static const QRegularExpression ipv6MappedRX1{QStringLiteral("^::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)$")};
+	static const QRegularExpression ipv6MappedRX2{QStringLiteral("^::[fF]{4}:(\\d+.\\d+.\\d+.\\d+):(\\d+)$")};
+	static const QRegularExpression ipv6MappedRX3{QStringLiteral("^\\[::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)\\]:(\\d+)$")};
+	static const QRegularExpression ipv6WithPortRX{QStringLiteral("^\\[([0-9a-fA-F:]+)\\]:(\\d+)$")};
+	static const QRegularExpression ipv6IrregularWithPortRX{QStringLiteral("^([0-9a-fA-F:]+):(\\d{5})$"), QRegularExpression::InvertedGreedinessOption};
+	static const QRegularExpression anyWithPortRX{QStringLiteral("^([^:]+):(\\d+)$")};
+
 	QRegularExpressionMatch match;
 	if(
 		// if IPv6-mapped IPv4 address use plain IPv4 address as libvncclient cannot handle IPv6-mapped IPv4 addresses on Windows properly
-		( match = QRegularExpression( QStringLiteral("^::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)$") ).match( m_host ) ).hasMatch() ||
-		( match = QRegularExpression( QStringLiteral("^::[fF]{4}:(\\d+.\\d+.\\d+.\\d+):(\\d+)$") ).match( m_host ) ).hasMatch() ||
-		( match = QRegularExpression( QStringLiteral("^\\[::[fF]{4}:(\\d+.\\d+.\\d+.\\d+)\\]:(\\d+)$") ).match( m_host ) ).hasMatch() ||
+		(match = ipv6MappedRX1.match(m_host)).hasMatch() ||
+		(match = ipv6MappedRX2.match(m_host)).hasMatch() ||
+		(match = ipv6MappedRX3.match(m_host)).hasMatch() ||
 		// any other IPv6 address with port number
-		( match = QRegularExpression( QStringLiteral("^\\[([0-9a-fA-F:]+)\\]:(\\d+)$") ).match( m_host ) ).hasMatch() ||
+		(match = ipv6WithPortRX.match(m_host)).hasMatch() ||
 		// irregular IPv6 address + port number specification where port number can be identified if > 9999
-		( match = QRegularExpression( QStringLiteral("^([0-9a-fA-F:]+):(\\d{5})$"), QRegularExpression::InvertedGreedinessOption ).match( m_host ) ).hasMatch() ||
+		(match = ipv6IrregularWithPortRX.match(m_host)).hasMatch() ||
 		// any other notation with trailing port number
-		( match = QRegularExpression( QStringLiteral("^([^:]+):(\\d+)$") ).match( m_host ) ).hasMatch()
+		(match = anyWithPortRX.match(m_host)).hasMatch()
 		)
 	{
 		const auto matchedHost = match.captured( 1 );
@@ -319,6 +334,19 @@ void VncConnection::setPort( int port )
 
 
 
+void VncConnection::setQuality(VncConnectionConfiguration::Quality quality)
+{
+	m_quality = quality;
+
+	if (m_client)
+	{
+		updateEncodingSettingsFromQuality();
+		enqueueEvent(new VncUpdateFormatAndEncodingsEvent);
+	}
+}
+
+
+
 void VncConnection::setUseRemoteCursor( bool enabled )
 {
 	m_useRemoteCursor = enabled;
@@ -365,12 +393,15 @@ void VncConnection::setFramebufferUpdateInterval( int interval )
 {
 	m_framebufferUpdateInterval = interval;
 
-	if (m_framebufferUpdateInterval <= 0)
+	if (state() == State::Connected)
 	{
-		setControlFlag(ControlFlag::TriggerFramebufferUpdate, true);
-	}
+		if (m_framebufferUpdateInterval <= 0)
+		{
+			setControlFlag(ControlFlag::TriggerFramebufferUpdate, true);
+		}
 
-	m_updateIntervalSleeper.wakeAll();
+		m_updateIntervalSleeper.wakeAll();
+	}
 }
 
 
@@ -390,7 +421,7 @@ void VncConnection::rescaleFramebuffer()
 
 	QReadLocker locker( &m_imgLock );
 
-	if( m_image.size().isValid() == false )
+	if (m_image.isNull() || m_image.size().isValid() == false)
 	{
 		return;
 	}
@@ -430,9 +461,17 @@ void VncConnection::run()
 {
 	while( isControlFlagSet( ControlFlag::TerminateThread ) == false )
 	{
+		QElapsedTimer connectionTimer;
+		connectionTimer.start();
+
 		establishConnection();
 		handleConnection();
 		closeConnection();
+
+		const auto minimumConnectionTime = m_framebufferUpdateInterval > 0 ?
+											   int(m_framebufferUpdateInterval) :
+											   m_connectionRetryInterval;
+		QThread::msleep(std::max<int>(0, minimumConnectionTime - connectionTimer.elapsed()));
 	}
 
 	if( isControlFlagSet( ControlFlag::DeleteAfterFinished ) )
@@ -455,6 +494,7 @@ void VncConnection::establishConnection()
 	while( isControlFlagSet( ControlFlag::TerminateThread ) == false &&
 		   state() != State::Connected ) // try to connect as long as the server allows
 	{
+		m_globalMutex.lock();
 		m_client = rfbGetClient( RfbBitsPerSample, RfbSamplesPerPixel, RfbBytesPerPixel );
 		m_client->MallocFrameBuffer = hookInitFrameBuffer;
 		m_client->canHandleNewFBSize = true;
@@ -465,6 +505,8 @@ void VncConnection::establishConnection()
 		m_client->GotXCutText = hookCutText;
 		m_client->connectTimeout = m_connectTimeout / 1000;
 		m_client->readTimeout = m_readTimeout / 1000;
+		m_globalMutex.unlock();
+
 		setClientData( VncConnectionTag, this );
 
 		Q_EMIT connectionPrepared();
@@ -502,7 +544,8 @@ void VncConnection::establishConnection()
 
 		if( clientInitialized )
 		{
-			m_framebufferUpdateWatchdog.restart();
+			m_fullFramebufferUpdateTimer.restart();
+			m_incrementalFramebufferUpdateTimer.restart();
 
 			VeyonCore::platform().networkFunctions().
 					configureSocketKeepalive( static_cast<PlatformNetworkFunctions::Socket>( m_client->sock ), true,
@@ -515,15 +558,26 @@ void VncConnection::establishConnection()
 			// guess reason why connection failed
 			if( isControlFlagSet( ControlFlag::ServerReachable ) == false )
 			{
-				if( isControlFlagSet( ControlFlag::SkipHostPing ) ||
-					VeyonCore::platform().networkFunctions().ping( m_host ) == false )
+				if (isControlFlagSet(ControlFlag::SkipHostPing))
 				{
-					setState( State::HostOffline );
+					setState(State::HostOffline);
 				}
 				else
 				{
-					setState( State::ServerNotRunning );
+					const auto pingResult = VeyonCore::platform().networkFunctions().ping(m_host);
+					switch (pingResult)
+					{
+					case PlatformNetworkFunctions::PingResult::ReplyReceived:
+						setState(State::ServerNotRunning);
+						break;
+					case PlatformNetworkFunctions::PingResult::NameResolutionFailed:
+						setState(State::HostNameResolutionFailed);
+						break;
+					default:
+						setState(State::HostOffline);
+					}
 				}
+
 			}
 			else if( m_framebufferState == FramebufferState::Invalid )
 			{
@@ -564,8 +618,13 @@ void VncConnection::handleConnection()
 	{
 		loopTimer.start();
 
-		const int i = WaitForMessage(m_client, m_framebufferUpdateInterval > 0 ?
-													m_messageWaitTimeout * 100 : m_messageWaitTimeout);
+		const auto waitTimeout = isControlFlagSet(ControlFlag::SkipFramebufferUpdates) ?
+									 m_messageWaitTimeout / 10
+								   :
+									 (m_framebufferUpdateInterval > 0 ? m_messageWaitTimeout * 100 : m_messageWaitTimeout);
+
+		const int i = WaitForMessage(m_client, waitTimeout);
+
 		if( isControlFlagSet( ControlFlag::TerminateThread ) || i < 0 )
 		{
 			break;
@@ -583,21 +642,21 @@ void VncConnection::handleConnection()
 				break;
 			}
 		}
-		else if (m_framebufferUpdateWatchdog.elapsed() >=
-				 qMax<qint64>(2*m_framebufferUpdateInterval, m_framebufferUpdateWatchdogTimeout))
+		else if (m_fullFramebufferUpdateTimer.elapsed() >= fullFramebufferUpdateTimeout())
 		{
-			SendFramebufferUpdateRequest(m_client, 0, 0, m_client->width, m_client->height, false);
-			m_framebufferUpdateWatchdog.restart();
+			requestFrameufferUpdate(FramebufferUpdateType::Full);
+			m_fullFramebufferUpdateTimer.restart();
 		}
-		else if (m_framebufferUpdateInterval > 0 && m_framebufferUpdateWatchdog.elapsed() > m_framebufferUpdateInterval)
+		else if (m_framebufferUpdateInterval > 0 &&
+				 m_incrementalFramebufferUpdateTimer.elapsed() > incrementalFramebufferUpdateTimeout())
 		{
-			SendIncrementalFramebufferUpdateRequest(m_client);
-			m_framebufferUpdateWatchdog.restart();
+			requestFrameufferUpdate(FramebufferUpdateType::Incremental);
+			m_incrementalFramebufferUpdateTimer.restart();
 		}
 		else if (isControlFlagSet(ControlFlag::TriggerFramebufferUpdate))
 		{
 			setControlFlag(ControlFlag::TriggerFramebufferUpdate, false);
-			SendIncrementalFramebufferUpdateRequest(m_client);
+			requestFrameufferUpdate(FramebufferUpdateType::Incremental);
 		}
 
 		const auto remainingUpdateInterval = m_framebufferUpdateInterval - loopTimer.elapsed();
@@ -692,27 +751,10 @@ bool VncConnection::initFrameBuffer()
 	m_client->format.greenMax = 0xff;
 	m_client->format.blueMax = 0xff;
 
-	m_client->appData.encodingsString = "zrle ultra copyrect hextile zlib corre rre raw";
 	m_client->appData.useRemoteCursor = m_useRemoteCursor ? TRUE : FALSE;
-	m_client->appData.compressLevel = 0;
 	m_client->appData.useBGR233 = false;
-	m_client->appData.qualityLevel = 9;
-	m_client->appData.enableJPEG = false;
 
-	switch( m_quality )
-	{
-	case Quality::Screenshot:
-		// make sure to use lossless raw encoding
-		m_client->appData.encodingsString = "raw";
-		break;
-	case Quality::Thumbnail:
-		m_client->appData.compressLevel = 9;
-		m_client->appData.qualityLevel = 5;
-		m_client->appData.enableJPEG = true;
-		break;
-	default:
-		break;
-	}
+	updateEncodingSettingsFromQuality();
 
 	m_framebufferState = FramebufferState::Initialized;
 
@@ -723,9 +765,28 @@ bool VncConnection::initFrameBuffer()
 
 
 
+void VncConnection::requestFrameufferUpdate(FramebufferUpdateType updateType)
+{
+	if (isControlFlagSet(ControlFlag::SkipFramebufferUpdates) == false)
+	{
+		switch (updateType)
+		{
+		case FramebufferUpdateType::Incremental:
+			SendIncrementalFramebufferUpdateRequest(m_client);
+			break;
+		case FramebufferUpdateType::Full:
+			SendFramebufferUpdateRequest(m_client, 0, 0, m_client->width, m_client->height, false);
+			break;
+		}
+	}
+}
+
+
+
 void VncConnection::finishFrameBufferUpdate()
 {
-	m_framebufferUpdateWatchdog.restart();
+	m_incrementalFramebufferUpdateTimer.restart();
+	m_fullFramebufferUpdateTimer.restart();
 
 	m_framebufferState = FramebufferState::Valid;
 	setControlFlag( ControlFlag::ScaledFramebufferNeedsUpdate, true );
@@ -735,6 +796,51 @@ void VncConnection::finishFrameBufferUpdate()
 
 
 
+int VncConnection::fullFramebufferUpdateTimeout() const
+{
+	return m_framebufferState == FramebufferState::Valid ?
+				m_framebufferUpdateTimeout
+			  :
+				std::max(int(m_framebufferUpdateInterval), m_initialFramebufferUpdateTimeout);
+}
+
+
+
+int VncConnection::incrementalFramebufferUpdateTimeout() const
+{
+	return m_framebufferState == FramebufferState::Valid ?
+				int(m_framebufferUpdateInterval)
+			  :
+				std::min(int(m_framebufferUpdateInterval), m_initialFramebufferUpdateTimeout);
+}
+
+
+
+void VncConnection::updateEncodingSettingsFromQuality()
+{
+	m_client->appData.encodingsString = m_quality == VncConnectionConfiguration::Quality::Highest ?
+											"zrle ultra copyrect hextile zlib corre rre raw" :
+											"tight zywrle zrle ultra";
+
+	m_client->appData.compressLevel = 9;
+
+	m_client->appData.qualityLevel = [this] {
+		switch(m_quality)
+		{
+		case VncConnectionConfiguration::Quality::Highest: return 9;
+		case VncConnectionConfiguration::Quality::High: return 7;
+		case VncConnectionConfiguration::Quality::Medium: return 5;
+		case VncConnectionConfiguration::Quality::Low: return 3;
+		case VncConnectionConfiguration::Quality::Lowest: return 0;
+		}
+		return 5;
+	}();
+
+	m_client->appData.enableJPEG = m_quality != VncConnectionConfiguration::Quality::Highest;
+}
+
+
+
 void VncConnection::sendEvents()
 {
 	m_eventQueueMutex.lock();
