@@ -1,7 +1,7 @@
 /*
  * VncConnection.h - declaration of VncConnection class
  *
- * Copyright (c) 2008-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2008-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -36,8 +36,9 @@
 #include <QTimer>
 #include <QWaitCondition>
 
-#include "VeyonCore.h"
 #include "SocketDevice.h"
+#include "VeyonCore.h"
+#include "VncConnectionConfiguration.h"
 
 using rfbClient = struct _rfbClient;
 
@@ -47,26 +48,6 @@ class VEYON_CORE_EXPORT VncConnection : public QThread
 {
 	Q_OBJECT
 public:
-	// intervals and timeouts
-	static constexpr int DefaultThreadTerminationTimeout = 30000;
-	static constexpr int DefaultConnectTimeout = 10000;
-	static constexpr int DefaultReadTimeout = 30000;
-	static constexpr int DefaultConnectionRetryInterval = 1000;
-	static constexpr int DefaultMessageWaitTimeout = 500;
-	static constexpr int DefaultFastFramebufferUpdateInterval = 100;
-	static constexpr int DefaultFramebufferUpdateWatchdogTimeout = 10000;
-	static constexpr int DefaultSocketKeepaliveIdleTime = 1000;
-	static constexpr int DefaultSocketKeepaliveInterval = 500;
-	static constexpr int DefaultSocketKeepaliveCount = 5;
-
-	enum class Quality
-	{
-		Thumbnail,
-		Screenshot,
-		RemoteControl,
-		Default
-	} ;
-
 	enum class FramebufferState
 	{
 		Invalid,
@@ -74,14 +55,22 @@ public:
 		Valid
 	} ;
 
+	enum class FramebufferUpdateType
+	{
+		Full,
+		Incremental
+	};
+
 	enum class State
 	{
 		None,
 		Disconnected,
 		Connecting,
 		HostOffline,
+		HostNameResolutionFailed,
 		ServerNotRunning,
 		AuthenticationFailed,
+		AccessControlFailed,
 		ConnectionFailed,
 		Connected
 	} ;
@@ -115,10 +104,7 @@ public:
 		return m_host;
 	}
 
-	void setQuality( Quality quality )
-	{
-		m_quality = quality ;
-	}
+	void setQuality(VncConnectionConfiguration::Quality quality);
 
 	void setUseRemoteCursor( bool enabled );
 
@@ -139,6 +125,11 @@ public:
 
 	void setFramebufferUpdateInterval( int interval );
 
+	void setSkipFramebufferUpdates(bool on)
+	{
+		setControlFlag(ControlFlag::SkipFramebufferUpdates, on);
+	}
+
 	void setSkipHostPing( bool on )
 	{
 		setControlFlag( ControlFlag::SkipHostPing, on );
@@ -191,7 +182,8 @@ private:
 		DeleteAfterFinished = 0x10,
 		SkipHostPing = 0x20,
 		RequiresManualUpdateRateControl = 0x40,
-		TriggerFramebufferUpdate = 0x80
+		TriggerFramebufferUpdate = 0x80,
+		SkipFramebufferUpdates = 0x100
 	};
 
 	~VncConnection() override;
@@ -206,8 +198,14 @@ private:
 	bool isControlFlagSet( ControlFlag flag );
 
 	bool initFrameBuffer();
+	void requestFrameufferUpdate(FramebufferUpdateType updateType);
 	void finishFrameBufferUpdate();
 
+	int fullFramebufferUpdateTimeout() const;
+	int incrementalFramebufferUpdateTimeout() const;
+
+	void updateEncodingSettingsFromQuality();
+
 	void sendEvents();
 
 	void deleteLaterInMainThread();
@@ -224,16 +222,17 @@ private:
 	static void framebufferCleanup( void* framebuffer );
 
 	// intervals and timeouts
-	int m_threadTerminationTimeout{DefaultThreadTerminationTimeout};
-	int m_connectTimeout{DefaultConnectTimeout};
-	int m_readTimeout{DefaultReadTimeout};
-	int m_connectionRetryInterval{DefaultConnectionRetryInterval};
-	int m_messageWaitTimeout{DefaultMessageWaitTimeout};
-	int m_fastFramebufferUpdateInterval{DefaultFastFramebufferUpdateInterval};
-	int m_framebufferUpdateWatchdogTimeout{DefaultFramebufferUpdateWatchdogTimeout};
-	int m_socketKeepaliveIdleTime{DefaultSocketKeepaliveIdleTime};
-	int m_socketKeepaliveInterval{DefaultSocketKeepaliveInterval};
-	int m_socketKeepaliveCount{DefaultSocketKeepaliveCount};
+	int m_threadTerminationTimeout{VncConnectionConfiguration::DefaultThreadTerminationTimeout};
+	int m_connectTimeout{VncConnectionConfiguration::DefaultConnectTimeout};
+	int m_readTimeout{VncConnectionConfiguration::DefaultReadTimeout};
+	int m_connectionRetryInterval{VncConnectionConfiguration::DefaultConnectionRetryInterval};
+	int m_messageWaitTimeout{VncConnectionConfiguration::DefaultMessageWaitTimeout};
+	int m_fastFramebufferUpdateInterval{VncConnectionConfiguration::DefaultFastFramebufferUpdateInterval};
+	int m_initialFramebufferUpdateTimeout{VncConnectionConfiguration::DefaultInitialFramebufferUpdateTimeout};
+	int m_framebufferUpdateTimeout{VncConnectionConfiguration::DefaultFramebufferUpdateTimeout};
+	int m_socketKeepaliveIdleTime{VncConnectionConfiguration::DefaultSocketKeepaliveIdleTime};
+	int m_socketKeepaliveInterval{VncConnectionConfiguration::DefaultSocketKeepaliveInterval};
+	int m_socketKeepaliveCount{VncConnectionConfiguration::DefaultSocketKeepaliveCount};
 
 	// states and flags
 	std::atomic<State> m_state;
@@ -242,7 +241,7 @@ private:
 
 	// connection parameters and data
 	rfbClient* m_client;
-	Quality m_quality;
+	VncConnectionConfiguration::Quality m_quality = VncConnectionConfiguration::Quality::Highest;
 	QString m_host;
 	int m_port;
 	int m_defaultPort{-1};
@@ -253,7 +252,8 @@ private:
 	QMutex m_eventQueueMutex;
 	QWaitCondition m_updateIntervalSleeper;
 	QAtomicInt m_framebufferUpdateInterval;
-	QElapsedTimer m_framebufferUpdateWatchdog;
+	QElapsedTimer m_fullFramebufferUpdateTimer{};
+	QElapsedTimer m_incrementalFramebufferUpdateTimer{};
 
 	// queue for RFB and custom events
 	QQueue<VncEvent *> m_eventQueue;
