@@ -1,7 +1,7 @@
 /*
  * FeatureMessageEvent.cpp - implementation of FeatureMessageEvent
  *
- * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -42,8 +42,6 @@ void VncFeatureMessageEvent::fire( rfbClient* client )
 			 << m_featureMessage;
 
 	SocketDevice socketDevice( VncConnection::libvncClientDispatcher, client );
-	const char messageType = FeatureMessage::RfbMessageType;
-	socketDevice.write( &messageType, sizeof(messageType) );
 
-	m_featureMessage.send( &socketDevice );
+	m_featureMessage.sendAsRfbMessage(&socketDevice);
 }
