@@ -1,7 +1,7 @@
 /*
  * VncServerProtocol.cpp - implementation of the VncServerProtocol class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,24 +28,20 @@
 #include <QRegularExpression>
 #include <QTcpSocket>
 
-#include "AuthenticationCredentials.h"
+#include "AccessControlProvider.h"
+#include "BuiltinFeatures.h"
 #include "VariantArrayMessage.h"
 #include "VncServerClient.h"
 #include "VncServerProtocol.h"
 
 
 
-VncServerProtocol::VncServerProtocol( QIODevice* socket,
-									  VncServerClient* client ) :
+VncServerProtocol::VncServerProtocol(QTcpSocket* socket, VncServerClient* client) :
 	m_socket( socket ),
 	m_client( client ),
 	m_serverInitMessage()
 {
-	auto qtcpSocket = qobject_cast<QTcpSocket *>(socket);
-	if (qtcpSocket)
-	{
-		m_client->setHostAddress(qtcpSocket->peerAddress().toString());
-	}
+	m_client->setHostAddress(m_socket->peerAddress().toString());
 	m_client->setAccessControlState( VncServerClient::AccessControlState::Init );
 }
 
@@ -60,7 +56,7 @@ VncServerProtocol::State VncServerProtocol::state() const
 
 void VncServerProtocol::start()
 {
-	if( state() == Disconnected )
+	if( state() == State::Disconnected )
 	{
 		rfbProtocolVersionMsg protocol; // Flawfinder: ignore
 
@@ -68,7 +64,7 @@ void VncServerProtocol::start()
 
 		m_socket->write( protocol, sz_rfbProtocolVersionMsg );
 
-		setState( Protocol );
+		setState( State::Protocol );
 	}
 }
 
@@ -78,29 +74,40 @@ bool VncServerProtocol::read()
 {
 	switch( state() )
 	{
-	case Protocol:
+	case State::Protocol:
 		return readProtocol();
 
-	case SecurityInit:
+	case State::SecurityInit:
 		return receiveSecurityTypeResponse();
 
-	case AuthenticationTypes:
+	case State::AuthenticationTypes:
 		return receiveAuthenticationTypeResponse();
 
-	case Authenticating:
+	case State::Authenticating:
 		return receiveAuthenticationMessage();
 
-	case AccessControl:
+	case State::AccessControl:
 		return processAccessControl();
 
-	case FramebufferInit:
+	case State::FramebufferInit:
 		return processFramebufferInit();
 
-	case Close:
+	case State::Close:
 		vDebug() << "closing connection per protocol state";
 		m_socket->close();
 		break;
 
+	case State::Closing:
+		if (m_socket->isOpen())
+		{
+			m_socket->readAll();
+		}
+		else
+		{
+			setState(State::Close);
+		}
+		return false;
+
 	default:
 		break;
 	}
@@ -130,15 +137,15 @@ bool VncServerProtocol::readProtocol()
 			return false;
 		}
 
-		if( QRegularExpression{ QStringLiteral("RFB (\\d\\d\\d)\\.(\\d\\d\\d)\n") }
-				.match( QString::fromUtf8( protocol ) ).hasMatch() == false )
+		static const QRegularExpression rfbRX{QStringLiteral("RFB (\\d\\d\\d)\\.(\\d\\d\\d)\n")};
+		if (rfbRX.match(QString::fromUtf8(protocol)).hasMatch() == false)
 		{
 			vCritical() << "invalid protocol version";
 			m_socket->close();
 			return false;
 		}
 
-		setState( SecurityInit );
+		setState( State::SecurityInit );
 
 		return sendSecurityTypes();
 	}
@@ -174,7 +181,7 @@ bool VncServerProtocol::receiveSecurityTypeResponse()
 			return false;
 		}
 
-		setState( AuthenticationTypes );
+		setState(State::AuthenticationTypes);
 
 		return sendAuthenticationTypes();
 	}
@@ -207,7 +214,7 @@ bool VncServerProtocol::receiveAuthenticationTypeResponse()
 
 	if( message.isReadyForReceive() && message.receive() )
 	{
-		const auto chosenAuthType = QVariantHelper<RfbVeyonAuth::Type>::value( message.read() );
+		const auto chosenAuthType = message.read().value<RfbVeyonAuth::Type>();
 
 		if( supportedAuthTypes().contains( chosenAuthType ) == false )
 		{
@@ -222,7 +229,7 @@ bool VncServerProtocol::receiveAuthenticationTypeResponse()
 		m_client->setAuthType( chosenAuthType );
 		m_client->setUsername( username );
 
-		setState( Authenticating );
+		setState( State::Authenticating );
 
 		// send auth ack message
 		VariantArrayMessage( m_socket ).send();
@@ -262,7 +269,7 @@ bool VncServerProtocol::processAuthentication( VariantArrayMessage& message )
 		const auto authResult = qToBigEndian<uint32_t>(rfbVncAuthOK);
 		m_socket->write( reinterpret_cast<const char *>( &authResult ), sizeof(authResult) );
 
-		setState( AccessControl );
+		setState( State::AccessControl );
 		return true;
 	}
 
@@ -288,7 +295,7 @@ bool VncServerProtocol::processAccessControl()
 	switch( m_client->accessControlState() )
 	{
 	case VncServerClient::AccessControlState::Successful:
-		setState( FramebufferInit );
+		setState( State::FramebufferInit );
 		return true;
 
 	case VncServerClient::AccessControlState::Pending:
@@ -297,8 +304,10 @@ bool VncServerProtocol::processAccessControl()
 
 	default:
 		vCritical() << "access control failed - closing connection";
-		m_socket->close();
-		break;
+		m_socket->read(sz_rfbClientInitMsg);
+		sendEmptyServerInitMessage();
+		sendFailedAccessControlDetails();
+		return true;
 	}
 
 	return false;
@@ -306,6 +315,29 @@ bool VncServerProtocol::processAccessControl()
 
 
 
+void VncServerProtocol::sendFailedAccessControlDetails()
+{
+	VeyonCore::builtinFeatures().accessControlProvider().sendDetails(m_socket, client()->accessControlDetails());
+
+	QObject::connect (&m_accessControlDetailsSendTimer, &QTimer::timeout, m_socket, [this]() {
+		VeyonCore::builtinFeatures().accessControlProvider().sendDetails(m_socket, client()->accessControlDetails());
+	});
+	QTimer::singleShot(AccessControlCloseDelay, m_socket, &QAbstractSocket::close);
+	m_accessControlDetailsSendTimer.start(AccessControlDetailsSendInterval);
+
+	setState(State::Closing);
+}
+
+
+
+void VncServerProtocol::sendEmptyServerInitMessage()
+{
+	rfbServerInitMsg message{};
+	m_socket->write(reinterpret_cast<const char *>(&message), sizeof(message));
+}
+
+
+
 bool VncServerProtocol::processFramebufferInit()
 {
 	if( m_socket->bytesAvailable() >= sz_rfbClientInitMsg &&
@@ -316,7 +348,7 @@ bool VncServerProtocol::processFramebufferInit()
 
 		m_socket->write( m_serverInitMessage );
 
-		setState( Running );
+		setState( State::Running );
 
 		return true;
 	}
