@@ -1,7 +1,7 @@
 /*
  * ComputerControlListModel.h - data model for computer control objects
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -66,11 +66,14 @@ private:
 	void update();
 
 	QModelIndex interfaceIndex( ComputerControlInterface* controlInterface ) const;
+	QVariant uidRoleData(const ComputerControlInterface::Pointer& controlInterface) const;
 
 	void updateState( const QModelIndex& index );
+	void updateAccessControlDetails(const QModelIndex& index);
 	void updateScreen( const QModelIndex& index );
 	void updateActiveFeatures( const QModelIndex& index );
 	void updateUser( const QModelIndex& index );
+	void updateSessionInfo(const QModelIndex& index);
 
 	void startComputerControlInterface( ComputerControlInterface* controlInterface );
 	void stopComputerControlInterface( const ComputerControlInterface::Pointer& controlInterface );
@@ -83,14 +86,16 @@ private:
 	QString computerDisplayRole( const ComputerControlInterface::Pointer& controlInterface ) const;
 	QString computerSortRole( const ComputerControlInterface::Pointer& controlInterface ) const;
 	static QString computerStateDescription( const ComputerControlInterface::Pointer& controlInterface );
-	static QString loggedOnUserInformation( const ComputerControlInterface::Pointer& controlInterface );
-	QString activeFeatures( const ComputerControlInterface::Pointer& controlInterface ) const;
+	static QString userInformation(const ComputerControlInterface::Pointer& controlInterface);
+	static QString activeFeaturesInformation(const ComputerControlInterface::Pointer& controlInterface);
 
 	VeyonMaster* m_master;
 
-	QImage m_iconDefault;
-	QImage m_iconConnectionProblem;
-	QImage m_iconServerNotRunning;
+	QImage m_iconHostOffline;
+	QImage m_iconHostOnline;
+	QImage m_iconHostNameResolutionFailed;
+	QImage m_iconHostAccessDenied;
+	QImage m_iconHostServiceError;
 
 	QSize m_computerScreenSize{};
 
