@@ -1,7 +1,7 @@
 /*
  * ComputerManager.cpp - maintains and provides a computer object list
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -27,6 +27,7 @@
 #include <QHostAddress>
 #include <QHostInfo>
 #include <QMessageBox>
+#include <QTime>
 
 #include "ComputerManager.h"
 #include "VeyonConfiguration.h"
@@ -45,11 +46,11 @@ ComputerManager::ComputerManager( UserConfig& config, QObject* parent ) :
 	m_config( config ),
 	m_networkObjectDirectory( VeyonCore::networkObjectDirectoryManager().configuredDirectory() ),
 	m_networkObjectModel( new NetworkObjectTreeModel( m_networkObjectDirectory, this ) ),
-	m_networkObjectOverlayDataModel( new NetworkObjectOverlayDataModel( tr( "User" ), this ) ),
+	m_networkObjectOverlayDataModel(new NetworkObjectOverlayDataModel({tr("User"), tr("Logged in since")}, this)),
 	m_computerTreeModel( new CheckableItemProxyModel( NetworkObjectModel::UidRole, this ) ),
 	m_networkObjectFilterProxyModel( new NetworkObjectFilterProxyModel( this ) ),
 	m_localHostNames( QHostInfo::localHostName().toLower() ),
-	m_localHostAddresses( QHostInfo::fromName( QHostInfo::localHostName() ).addresses() )
+	m_localHostAddresses(QHostInfo::fromName(QHostInfo::localHostName()).addresses())
 {
 	if( m_networkObjectDirectory == nullptr )
 	{
@@ -118,7 +119,7 @@ bool ComputerManager::saveComputerAndUsersList( const QString& fileName )
 			// fetch user
 			const auto user = m_networkObjectOverlayDataModel->data( mapToUserNameModelIndex( networkObjectIndex ) ).toString();
 			// create new line with computer and user
-			lines += computer.name() + QLatin1Char(';') + computer.hostAddress() + QLatin1Char(';') + user; // clazy:exclude=reserve-candidates
+			lines += computer.displayName() + QLatin1Char(';') + computer.hostName() + QLatin1Char(';') + user; // clazy:exclude=reserve-candidates
 		}
 	}
 
@@ -152,9 +153,72 @@ void ComputerManager::updateUser(const ComputerControlInterface::Pointer& contro
 		{
 			user = controlInterface->userLoginName();
 		}
-		m_networkObjectOverlayDataModel->setData( mapToUserNameModelIndex( networkObjectIndex ),
-												  user,
-												  Qt::DisplayRole );
+		m_networkObjectOverlayDataModel->setData(mapToUserNameModelIndex(networkObjectIndex), user);
+
+		if (controlInterface->computerNameSource() == Computer::NameSource::UserFullName ||
+			controlInterface->computerNameSource() == Computer::NameSource::UserLoginName)
+		{
+			const auto computerName = controlInterface->computerName();
+			if (computerName.isEmpty() == false)
+			{
+				m_networkObjectOverlayDataModel->setData(m_networkObjectOverlayDataModel->mapFromSource(networkObjectIndex),
+														 computerName);
+			}
+		}
+	}
+}
+
+
+
+void ComputerManager::updateSessionInfo(const ComputerControlInterface::Pointer& controlInterface) const
+{
+	const auto networkObjectIndex = findNetworkObject(controlInterface->computer().networkObjectUid());
+
+	if (networkObjectIndex.isValid())
+	{
+		const auto uptime24h = controlInterface->sessionInfo().uptime % (60*60*24);
+		const auto uptimeDays = controlInterface->sessionInfo().uptime / (60*60*24);
+		const QString uptimeString = (uptimeDays > 0 ?
+										  ((uptimeDays > 1 ? tr("%1 days").arg(uptimeDays) : tr("1 day")) + QStringLiteral(", ")) :
+										  QString()) +
+									 QTime::fromMSecsSinceStartOfDay(uptime24h * 1000).toString(QStringLiteral("hh:mm:ss"));
+		m_networkObjectOverlayDataModel->setData(mapToSessionUptimeModelIndex(networkObjectIndex),
+												  uptimeString,
+												  Qt::DisplayRole);
+
+		switch (controlInterface->computerNameSource())
+		{
+		case Computer::NameSource::HostAddress:
+		case Computer::NameSource::SessionClientName:
+		case Computer::NameSource::SessionClientAddress:
+		case Computer::NameSource::SessionHostName:
+		case Computer::NameSource::SessionMetaData:
+		{
+			const auto computerName = controlInterface->computerName();
+			if (computerName.isEmpty() == false)
+			{
+				m_networkObjectOverlayDataModel->setData(m_networkObjectOverlayDataModel->mapFromSource(networkObjectIndex),
+														 computerName);
+			}
+			break;
+		}
+		default:
+			break;
+		}
+	}
+}
+
+
+
+void ComputerManager::clearOverlayModelData(const ComputerControlInterface::Pointer& controlInterface) const
+{
+	const auto networkObjectIndex = findNetworkObject(controlInterface->computer().networkObjectUid());
+
+	if (networkObjectIndex.isValid())
+	{
+		m_networkObjectOverlayDataModel->setData(mapToUserNameModelIndex(networkObjectIndex), {});
+		m_networkObjectOverlayDataModel->setData(mapToSessionUptimeModelIndex(networkObjectIndex), {});
+		m_networkObjectOverlayDataModel->setData(m_networkObjectOverlayDataModel->mapFromSource(networkObjectIndex), {});
 	}
 }
 
@@ -175,12 +239,12 @@ void ComputerManager::checkChangedData( const QModelIndex& topLeft, const QModel
 
 void ComputerManager::initLocations()
 {
-	for( const auto& hostName : qAsConst( m_localHostNames ) )
+	for( const auto& hostName : std::as_const( m_localHostNames ) )
 	{
 		vDebug() << "initializing locations for hostname" << hostName;
 	}
 
-	for( const auto& address : qAsConst( m_localHostAddresses ) )
+	for( const auto& address : std::as_const( m_localHostAddresses ) )
 	{
 		vDebug() << "initializing locations for host address" << address.toString();
 	}
@@ -234,7 +298,7 @@ void ComputerManager::initNetworkObjectLayer()
 
 		localHostNames.append( m_localHostNames );
 
-		for( const auto& address : qAsConst( m_localHostAddresses ) )
+		for( const auto& address : std::as_const( m_localHostAddresses ) )
 		{
 			localHostNames.append( address.toString() ); // clazy:exclude=reserve-candidates
 		}
@@ -247,7 +311,7 @@ void ComputerManager::initNetworkObjectLayer()
 			const auto sessionServerPort = QString::number( VeyonCore::config().veyonServerPort() +
 															 VeyonCore::sessionId() );
 
-			for( const auto& localHostName : qAsConst(localHostNames) )
+			for( const auto& localHostName : std::as_const(localHostNames) )
 			{
 				ownSessionNames.append( QStringLiteral("%1:%2").arg( localHostName, sessionServerPort ) );
 			}
@@ -277,7 +341,7 @@ void ComputerManager::initComputerTreeModel()
 	QJsonArray checkedNetworkObjects;
 	if( VeyonCore::config().autoSelectCurrentLocation() )
 	{
-		for( const auto& location : qAsConst( m_currentLocations ) )
+		for( const auto& location : std::as_const( m_currentLocations ) )
 		{
 			const auto computersAtLocation = getComputersAtLocation( location );
 			for( const auto& computer : computersAtLocation )
@@ -361,12 +425,10 @@ QString ComputerManager::findLocationOfComputer(const QStringList& hostNames, co
 
 
 
-ComputerList ComputerManager::getComputersAtLocation(const QString& locationName, const QModelIndex& parent) const
+ComputerList ComputerManager::getComputersAtLocation(const QString& locationName, const QModelIndex& parent, bool parentMatches) const
 {
 	QAbstractItemModel* model = computerTreeModel();
 
-	const bool parentMatches = model->data(parent, NetworkObjectModel::NameRole).toString() == locationName;
-
 	int rows = model->rowCount( parent );
 
 	ComputerList computers;
@@ -376,13 +438,13 @@ ComputerList ComputerManager::getComputersAtLocation(const QString& locationName
 	{
 		const auto entryIndex = model->index(i, 0, parent);
 		const auto objectType = NetworkObject::Type(model->data(entryIndex, NetworkObjectModel::TypeRole).toInt());
-
+		const auto objectName = model->data(entryIndex, NetworkObjectModel::NameRole).toString();
 		if( NetworkObject::isContainer(objectType) )
 		{
-			if (model->data(entryIndex, NetworkObjectModel::NameRole).toString() == locationName ||
-				hasSubLocations(entryIndex))
+			const auto currentLocationMatches = objectName == locationName;
+			if (parentMatches || currentLocationMatches || hasSubLocations(entryIndex))
 			{
-				computers += getComputersAtLocation( locationName, entryIndex );
+				computers += getComputersAtLocation(locationName, entryIndex, parentMatches || currentLocationMatches);
 			}
 		}
 		else if( objectType == NetworkObject::Type::Host )
@@ -390,7 +452,7 @@ ComputerList ComputerManager::getComputersAtLocation(const QString& locationName
 			if (parentMatches)
 			{
 				computers += Computer(model->data(entryIndex, NetworkObjectModel::UidRole).toUuid(),
-									  model->data(entryIndex, NetworkObjectModel::NameRole).toString(),
+									  objectName,
 									  model->data(entryIndex, NetworkObjectModel::HostAddressRole).toString(),
 									  model->data(entryIndex, NetworkObjectModel::MacAddressRole).toString());
 			}
@@ -435,7 +497,7 @@ ComputerList ComputerManager::selectedComputers(const QModelIndex& parent) const
 	{
 		QModelIndex entryIndex = model->index( i, 0, parent );
 
-		if( QVariantHelper<Qt::CheckState>::value( model->data( entryIndex, NetworkObjectModel::CheckStateRole ) ) == Qt::Unchecked )
+		if( model->data( entryIndex, NetworkObjectModel::CheckStateRole ).value<Qt::CheckState>() == Qt::Unchecked )
 		{
 			continue;
 		}
@@ -502,3 +564,13 @@ QModelIndex ComputerManager::mapToUserNameModelIndex(const QModelIndex& networkO
 
 	return m_networkObjectOverlayDataModel->index( networkObjectIndex.row(), OverlayDataUsernameColumn, parent );
 }
+
+
+
+QModelIndex ComputerManager::mapToSessionUptimeModelIndex(const QModelIndex& networkObjectIndex) const
+{
+	// map arbitrary index from m_networkObjectModel to username column in m_networkObjectOverlayDataModel
+	const auto parent = m_networkObjectOverlayDataModel->mapFromSource(networkObjectIndex.parent());
+
+	return m_networkObjectOverlayDataModel->index(networkObjectIndex.row(), OverlayDataSessionUptimeColumn, parent);
+}
