@@ -1,7 +1,7 @@
 /*
  * ComputerSelectPanel.cpp - provides a view for a network object tree
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -67,6 +67,13 @@ ComputerSelectPanel::ComputerSelectPanel( ComputerManager& computerManager, QWid
 
 	connect( ui->filterLineEdit, &QLineEdit::textChanged,
 			 this, &ComputerSelectPanel::updateFilter );
+
+	if (VeyonCore::config().expandLocations())
+	{
+		connect(m_filterProxyModel, &QAbstractItemModel::modelReset,
+				this, &ComputerSelectPanel::fetchAndExpandAll);
+		fetchAndExpandAll();
+	}
 }
 
 
@@ -111,7 +118,7 @@ void ComputerSelectPanel::removeLocation()
 	const auto index = ui->treeView->selectionModel()->currentIndex();
 
 	if( index.isValid() &&
-		QVariantHelper<NetworkObject::Type>::value( model->data( index, NetworkObjectModel::TypeRole ) ) == NetworkObject::Type::Location )
+		model->data( index, NetworkObjectModel::TypeRole ).value<NetworkObject::Type>() == NetworkObject::Type::Location )
 	{
 		m_computerManager.removeLocation( model->data( index, NetworkObjectModel::NameRole ).toString() );
 	}
@@ -175,3 +182,27 @@ void ComputerSelectPanel::updateFilter()
 		ui->treeView->expandAll();
 	}
 }
+
+
+
+void ComputerSelectPanel::fetchAndExpandAll()
+{
+	fetchAll(m_filterProxyModel->index(0, 0));
+	QTimer::singleShot(0, this, [this]{ui->treeView->expandAll();});
+}
+
+
+
+void ComputerSelectPanel::fetchAll(const QModelIndex& index)
+{
+	if (m_filterProxyModel->canFetchMore(index))
+	{
+		m_filterProxyModel->fetchMore(index);
+	}
+
+	const auto rowCount = m_filterProxyModel->rowCount(index);
+	for (int i = 0; i < rowCount; ++i)
+	{
+		fetchAll(m_filterProxyModel->index(i, 0, index));
+	}
+}
