@@ -1,7 +1,7 @@
 /*
  * ComputerSelectPanel.h - provides a view for a network object tree
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -51,6 +51,9 @@ private Q_SLOTS:
 	void updateFilter();
 
 private:
+	void fetchAndExpandAll();
+	void fetchAll(const QModelIndex& index);
+
 	Ui::ComputerSelectPanel *ui;
 	ComputerManager& m_computerManager;
 	QSortFilterProxyModel* m_filterProxyModel;
