@@ -1,7 +1,7 @@
 /*
  * MainWindow.cpp - implementation of MainWindow class
  *
- * Copyright (c) 2004-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2004-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -23,6 +23,8 @@
  */
 
 #include <QCloseEvent>
+#include <QFileDialog>
+#include <QJsonDocument>
 #include <QKeyEvent>
 #include <QHostAddress>
 #include <QMenu>
@@ -42,6 +44,7 @@
 #include "MonitoringMode.h"
 #include "NetworkObjectDirectory.h"
 #include "NetworkObjectDirectoryManager.h"
+#include "PlatformUserFunctions.h"
 #include "SlideshowPanel.h"
 #include "SpotlightPanel.h"
 #include "ToolButton.h"
@@ -75,7 +78,7 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 	ui->statusBar->addWidget( ui->gridSizeSlider, 2 );
 	ui->statusBar->addWidget( ui->autoAdjustComputerIconSizeButton );
 	ui->statusBar->addWidget( ui->spacerLabel3 );
-	ui->statusBar->addWidget( ui->useCustomComputerArrangementButton );
+	ui->statusBar->addWidget( ui->useCustomComputerPositionsButton );
 	ui->statusBar->addWidget( ui->alignComputersButton );
 	ui->statusBar->addWidget( ui->spacerLabel4 );
 	ui->statusBar->addWidget( ui->aboutButton );
@@ -195,15 +198,15 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 		ui->computerSelectPanelButton->setChecked( true );
 	}
 
-	// initialize search filter
-	ui->filterPoweredOnComputersButton->setChecked( m_master.userConfig().filterPoweredOnComputers() );
-	ui->filterComputersWithLoggedOnUsersButton->setChecked( m_master.userConfig().filterComputersWithLoggedOnUsers() );
+	// initialize filter controls
 	connect( ui->filterLineEdit, &QLineEdit::textChanged,
 			 this, [this]( const QString& filter ) { ui->computerMonitoringWidget->setSearchFilter( filter ); } );
 	connect( ui->filterPoweredOnComputersButton, &QToolButton::toggled,
 			 this, [this]( bool enabled ) { ui->computerMonitoringWidget->setFilterPoweredOnComputers( enabled ); } );
 	connect( ui->filterComputersWithLoggedOnUsersButton, &QToolButton::toggled,
 			 this, [this]( bool enabled ) { ui->computerMonitoringWidget->setFilterComputersWithLoggedOnUsers( enabled ); } );
+	ui->filterPoweredOnComputersButton->setChecked(m_master.userConfig().filterPoweredOnComputers());
+	ui->filterComputersWithLoggedOnUsersButton->setChecked(m_master.userConfig().filterComputersWithLoggedOnUsers());
 
 	// initialize monitoring screen size slider
 	ui->gridSizeSlider->setMinimum( ComputerMonitoringWidget::MinimumComputerScreenSize );
@@ -231,12 +234,38 @@ MainWindow::MainWindow( VeyonMaster &masterCore, QWidget* parent ) :
 	ui->computerMonitoringWidget->setComputerScreenSize( size );
 
 	// initialize computer placement controls
-	ui->useCustomComputerArrangementButton->setChecked( m_master.userConfig().useCustomComputerPositions() );
-	connect( ui->useCustomComputerArrangementButton, &QToolButton::toggled,
-			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::setUseCustomComputerPositions );
-	connect( ui->alignComputersButton, &QToolButton::clicked,
-			 ui->computerMonitoringWidget, &ComputerMonitoringWidget::alignComputers );
+	auto customComputerPositionsControlMenu = new QMenu;
+	const auto darkSuffix = VeyonCore::useDarkMode() ? QStringLiteral("-dark") : QString();
+	customComputerPositionsControlMenu->addAction(QIcon(QStringLiteral(":/core/document-open%1.png").arg(darkSuffix)),
+													tr("Load computer positions"),
+													this, &MainWindow::loadComputerPositions);
+	customComputerPositionsControlMenu->addAction(QIcon(QStringLiteral(":/core/document-save%1.png").arg(darkSuffix)),
+													tr("Save computer positions"),
+													this, &MainWindow::saveComputerPositions);
+	ui->useCustomComputerPositionsButton->setMenu(customComputerPositionsControlMenu);
 
+	ui->useCustomComputerPositionsButton->setChecked(m_master.userConfig().useCustomComputerPositions());
+	connect(ui->useCustomComputerPositionsButton, &QToolButton::toggled,
+			ui->computerMonitoringWidget, &ComputerMonitoringWidget::setUseCustomComputerPositions);
+	connect(ui->alignComputersButton, &QToolButton::clicked,
+			ui->computerMonitoringWidget, &ComputerMonitoringWidget::alignComputers);
+
+
+	const auto toolButtons = findChildren<QToolButton*>();
+	for(auto* btn : toolButtons)
+	{
+		btn->setIconSize(QSize(20, 20));
+	}
+
+	if (VeyonCore::useDarkMode())
+	{
+		ui->aboutButton->setIcon(QIcon(QStringLiteral(":/core/help-about-dark.png")));
+		ui->filterComputersWithLoggedOnUsersButton->setIcon(QIcon(QStringLiteral(":/core/user-group-new-dark.png")));
+		ui->autoAdjustComputerIconSizeButton->setIcon(QIcon(QStringLiteral(":/master/zoom-fit-best-dark.png")));
+		ui->alignComputersButton->setIcon(QIcon(QStringLiteral(":/master/align-grid-dark.png")));
+		ui->useCustomComputerPositionsButton->setIcon(QIcon(QStringLiteral(":/master/exchange-positions-zorder-dark.png")));
+		ui->filterPoweredOnComputersButton->setIcon(QIcon(QStringLiteral(":/master/powered-on-dark.png")));
+	}
 
 	// create the main toolbar
 	ui->toolBar->layout()->setSpacing( 2 );
@@ -289,14 +318,16 @@ bool MainWindow::initAuthentication()
 
 bool MainWindow::initAccessControl()
 {
-	if( VeyonCore::config().accessControlForMasterEnabled() &&
-			VeyonCore::authenticationCredentials().hasCredentials( AuthenticationCredentials::Type::UserLogon ) )
+	if (VeyonCore::config().accessControlForMasterEnabled())
 	{
-		const auto accessControlResult =
-				AccessControlProvider().checkAccess( VeyonCore::authenticationCredentials().logonUsername(),
-													 QHostAddress( QHostAddress::LocalHost ).toString(),
-													 QStringList() );
-		if( accessControlResult == AccessControlProvider::Access::Deny )
+		const auto accessingUser = VeyonCore::authenticationCredentials().hasCredentials(AuthenticationCredentials::Type::UserLogon) ?
+									   VeyonCore::authenticationCredentials().logonUsername() :
+									   VeyonCore::platform().userFunctions().currentUser();
+		const auto accessControlResult = VeyonCore::builtinFeatures().accessControlProvider()
+										 .checkAccess(accessingUser,
+													  QHostAddress(QHostAddress::LocalHost).toString(),
+													  {});
+		if( accessControlResult.access == AccessControlProvider::Access::Deny )
 		{
 			vWarning() << "user" << VeyonCore::authenticationCredentials().logonUsername()
 					   << "is not allowed to access computers";
@@ -490,35 +521,26 @@ void MainWindow::addSubFeaturesToToolButton( QToolButton* button, const Feature&
 
 	for( const auto& subFeature : subFeatures )
 	{
-#if QT_VERSION < 0x050600
-#warning Building legacy compat code for unsupported version of Qt
-		auto action = menu->addAction( QIcon( subFeature.iconUrl() ), subFeature.displayName() );
-		action->setShortcut( subFeature.shortcut() );
-		connect( action, &QAction::triggered, this,
-			[=]() {
-				m_master.runFeature( subFeature );
-				if( parentFeatureIsMode )
+		auto action = menu->addAction(QIcon(subFeature.iconUrl()), subFeature.displayName(),
+							   #if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+									   subFeature.shortcut(),
+							   #endif
+									   this, [=]()
+		{
+			m_master.runFeature( subFeature );
+			if( parentFeatureIsMode )
+			{
+				if( subFeature.testFlag( Feature::Flag::Option ) == false )
 				{
 					button->setChecked( true );
-					reloadSubFeatures();
 				}
+				reloadSubFeatures();
 			}
-		);
-#else
-		auto action = menu->addAction( QIcon( subFeature.iconUrl() ), subFeature.displayName(), this,
-			[=]() {
-				m_master.runFeature( subFeature );
-				if( parentFeatureIsMode )
-				{
-					if( subFeature.testFlag( Feature::Flag::Option ) == false )
-					{
-						button->setChecked( true );
-					}
-					reloadSubFeatures();
-				}
-			},
-			subFeature.shortcut() );
+		}
+#if QT_VERSION < QT_VERSION_CHECK(6, 3, 0)
+		,subFeature.shortcut()
 #endif
+		);
 		action->setToolTip( subFeature.description() );
 		action->setObjectName( subFeature.uid().toString() );
 
@@ -544,3 +566,49 @@ void MainWindow::updateModeButtonGroup()
 		m_modeGroup->button( buttonId( monitoringMode ) )->setChecked( true );
 	}
 }
+
+
+
+void MainWindow::loadComputerPositions()
+{
+	if (const auto fileName = QFileDialog::getOpenFileName(this, tr("Load computer positions"),
+														   QDir::homePath(), tr("JSON files (*.json)"));
+		!fileName.isEmpty())
+	{
+		if (QFile file(fileName); file.open(QFile::ReadOnly))
+		{
+			const auto& computerPositionsProperty = m_master.userConfig().computerPositionsProperty();
+			const auto config = QJsonDocument::fromJson(file.readAll()).object();
+			const auto uiConfig = config[computerPositionsProperty.parentKey()].toObject();
+			const auto computerPositions = uiConfig[computerPositionsProperty.key()].toObject()[QStringLiteral("JsonStoreArray")].toArray();
+
+			ui->computerMonitoringWidget->loadPositions(computerPositions);
+			ui->computerMonitoringWidget->setUseCustomComputerPositions(true);
+			ui->computerMonitoringWidget->doItemsLayout();
+		}
+	}
+}
+
+
+
+void MainWindow::saveComputerPositions()
+{
+	if (const auto fileName = QFileDialog::getSaveFileName(this, tr("Save computer positions"),
+														   QDir::homePath(), tr("JSON files (*.json)"));
+		!fileName.isEmpty())
+	{
+		if (QFile file(fileName); file.open(QFile::WriteOnly | QFile::Truncate))
+		{
+			const auto& computerPositionsProperty = m_master.userConfig().computerPositionsProperty();
+
+			// create structure identical to UserConfig so file with positions can be used as template for UserConfig
+			QJsonObject computerPositions;
+			computerPositions[QStringLiteral("JsonStoreArray")] = ui->computerMonitoringWidget->savePositions();
+			QJsonObject uiConfig;
+			uiConfig[computerPositionsProperty.key()] = computerPositions;
+			QJsonObject config;
+			config[computerPositionsProperty.parentKey()] = uiConfig;
+			file.write(QJsonDocument(config).toJson());
+		}
+	}
+}
