@@ -1,7 +1,7 @@
 /*
  * UserConfig.h - UserConfig class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -39,7 +39,8 @@ class UserConfig : public Configuration::Object
 {
 	Q_OBJECT
 public:
-	explicit UserConfig( Configuration::Store::Backend backend );
+	UserConfig(const QString& storeName);
+	explicit UserConfig(Configuration::Store* store);
 
 #define FOREACH_PERSONAL_CONFIG_PROPERTY(OP)						\
 	OP( UserConfig, VeyonMaster::userConfig(), QJsonArray, checkedNetworkObjects, setCheckedNetworkObjects, "CheckedNetworkObjects", "UI", QJsonArray(), Configuration::Property::Flag::Standard )	\
