@@ -1,7 +1,7 @@
 /*
  * AuthKeysManager.cpp - implementation of AuthKeysManager class
  *
- * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -461,8 +461,8 @@ QString AuthKeysManager::exportedKeyFileName( const QString& name, const QString
 
 QString AuthKeysManager::keyNameFromExportedKeyFile( const QString& keyFile )
 {
-	const auto keyNameMatch = QRegularExpression( QStringLiteral("^(.*)_(.*)_key.pem$") )
-								  .match(QFileInfo(keyFile).fileName());
+	static const QRegularExpression keyNameRX{QStringLiteral("^(.*)_(.*)_key.pem$")};
+	const auto keyNameMatch = keyNameRX.match(QFileInfo(keyFile).fileName());
 
 	if( keyNameMatch.hasMatch() )
 	{
