@@ -1,7 +1,7 @@
 /*
  * BuiltinDirectory.cpp - NetworkObjects from VeyonConfiguration
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -53,14 +53,15 @@ void BuiltinDirectory::update()
 		{
 			groupUids.append( networkObject.uid() ); // clazy:exclude=reserve-candidates
 
-			addOrUpdateObject( networkObject, NetworkObject( NetworkObject::Type::Root ) );
+			addOrUpdateObject(networkObject, rootObject());
 
 			updateLocation( networkObject, networkObjects );
 		}
 	}
 
-	removeObjects( NetworkObject( NetworkObject::Type::Root ), [groupUids]( const NetworkObject& object ) {
-		return object.type() == NetworkObject::Type::Location && groupUids.contains( object.uid() ) == false; } );
+	removeObjects(rootObject(), [groupUids](const NetworkObject& object) {
+		return object.type() == NetworkObject::Type::Location && groupUids.contains(object.uid()) == false;
+	});
 }
 
 
