@@ -1,7 +1,7 @@
 /*
  * DemoFeaturePlugin.cpp - implementation of DemoFeaturePlugin class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -35,6 +35,7 @@
 #include "FeatureWorkerManager.h"
 #include "HostAddress.h"
 #include "Logger.h"
+#include "PlatformPluginInterface.h"
 #include "PlatformSessionFunctions.h"
 #include "VeyonConfiguration.h"
 #include "VeyonMasterInterface.h"
@@ -214,7 +215,7 @@ bool DemoFeaturePlugin::startFeature( VeyonMasterInterface& master, const Featur
 		auto demoServerPort = VeyonCore::config().demoServerPort();
 
 		const auto& demoServerInterface = selectedComputerControlInterfaces.constFirst();
-		const auto demoServerHost = demoServerInterface->computer().hostAddress();
+		const auto demoServerHost = demoServerInterface->computer().hostName();
 		const auto primaryServerPort = HostAddress::parsePortNumber( demoServerHost );
 
 		if( primaryServerPort > 0 )
@@ -509,7 +510,7 @@ void DemoFeaturePlugin::updateFeatures()
 												   m_demoFeature.uid(), tr("All screens"), {}, {}, {} } );
 
 		int index = 1;
-		for( auto screen : qAsConst(m_screens) )
+		for( auto screen : std::as_const(m_screens) )
 		{
 			const auto name = QStringLiteral( "DemoScreen%1" ).arg( index );
 			const auto screenName = VeyonCore::screenName(*screen, index);
