@@ -1,7 +1,7 @@
 /*
  * DesktopServicesConfigurationPage.h - header for the DesktopServicesConfigurationPage class
  *
- * Copyright (c) 2018-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -46,9 +46,9 @@ public:
 	void applyConfiguration() override;
 
 private Q_SLOTS:
-	void addProgram();
-	void updateProgram();
-	void removeProgram();
+	void addApplication();
+	void updateApplication();
+	void removeApplication();
 	void addWebsite();
 	void updateWebsite();
 	void removeWebsite();
