@@ -1,7 +1,7 @@
 /*
  * DesktopServicesFeaturePlugin.h - declaration of DesktopServicesFeaturePlugin class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -42,7 +42,7 @@ public:
 	enum class Argument
 	{
 		Applications,
-		WebsiteUrl
+		WebsiteUrls
 	};
 	Q_ENUM(Argument)
 
