@@ -1,7 +1,7 @@
 /*
  * FileTransferController.cpp - implementation of FileTransferController class
  *
- * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -167,6 +167,8 @@ void FileTransferController::process()
 				m_plugin->sendOpenTransferFolderMessage( m_interfaces );
 			}
 
+			m_plugin->sendStopWorkerMessage(m_interfaces);
+
 			m_processTimer.stop();
 			Q_EMIT finished();
 		}
@@ -268,7 +270,7 @@ void FileTransferController::updateProgress()
 
 bool FileTransferController::allQueuesEmpty()
 {
-	for( const auto& controlInterface : qAsConst(m_interfaces) )
+	for( const auto& controlInterface : std::as_const(m_interfaces) )
 	{
 		if( controlInterface->isMessageQueueEmpty() == false )
 		{
