@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2023 Tobias Junghans <tobydox@veyon.io>
+// Copyright (c) 2019-2025 Tobias Junghans <tobydox@veyon.io>
 // This file is part of Veyon - https://veyon.io
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -73,13 +73,15 @@ LdapConfigurationPage::LdapConfigurationPage( LdapConfiguration& configuration,
 		ui->tlsCACertificateFile->setEnabled( ui->tlsVerifyMode->currentIndex() == LdapClient::TLSVerifyCustomCert );
 	} );
 
-	const auto browseButtons = findChildren<QPushButton *>( QRegularExpression( QStringLiteral("browse.*") ) );
+	static const QRegularExpression browseButtonsRX{QStringLiteral("browse.*")};
+	const auto browseButtons = findChildren<QPushButton *>(browseButtonsRX);
 	for( auto button : browseButtons )
 	{
 		button->setToolTip( tr( "Browse" ) );
 	}
 
-	const auto testButtons = findChildren<QPushButton *>( QRegularExpression( QStringLiteral("test.*") ) );
+	static const QRegularExpression testButtonsRX{QStringLiteral("test.*")};
+	const auto testButtons = findChildren<QPushButton *>( testButtonsRX );
 	for( auto button : testButtons )
 	{
 		button->setToolTip( tr( "Test" ) );
