@@ -1,7 +1,7 @@
 /*
  * LinuxCoreFunctions.cpp - implementation of LinuxCoreFunctions class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -41,6 +41,7 @@
 #include "LinuxDesktopIntegration.h"
 #include "LinuxUserFunctions.h"
 #include "PlatformUserFunctions.h"
+#include "ProcessHelper.h"
 
 #include <X11/XKBlib.h>
 #include <X11/extensions/dpms.h>
@@ -406,6 +407,21 @@ LinuxCoreFunctions::DBusInterfacePointer LinuxCoreFunctions::consoleKitManager()
 
 
 
+bool LinuxCoreFunctions::isSystemdManaged()
+{
+	if (QFile::exists(QStringLiteral("/sbin/systemd")) == false &&
+		QFile::exists(QStringLiteral("/usr/sbin/systemd")) == false &&
+		QFile::exists(QStringLiteral("/lib/systemd/systemd")) == false)
+	{
+		return false;
+	}
+
+	const auto status = ProcessHelper(QStringLiteral("systemctl"), {QStringLiteral("is-system-running")}).runAndReadAll().trimmed();
+	return status.isEmpty() == false && status != "offline";
+}
+
+
+
 int LinuxCoreFunctions::systemctl( const QStringList& arguments )
 {
 	QProcess process;
@@ -470,7 +486,7 @@ void LinuxCoreFunctions::forEachChildProcess( const std::function<bool(proc_t*)>
 	closeproc( proc );
 }
 #elif defined(HAVE_LIBPROC2)
-void LinuxCoreFunctions::forEachChildProcess(const std::function<bool(const pids_stack*, const pids_info*)>& visitor,
+void LinuxCoreFunctions::forEachChildProcess(const std::function<bool(const pids_stack*)>& visitor,
 											 int parentPid, const std::vector<pids_item>& items, bool visitParent)
 {
 	QProcessEnvironment sessionEnv;
@@ -492,18 +508,18 @@ void LinuxCoreFunctions::forEachChildProcess(const std::function<bool(const pids
 
 	while ((stack = procps_pids_get(info, PIDS_FETCH_TASKS_ONLY)))
 	{
-		const auto ppid = PIDS_VAL(PPidItemIndex, s_int, stack, info);
+		const auto ppid = PIDS_VAL(PPidItemIndex, s_int, stack);
 
 		if (ppid == parentPid)
 		{
-			if (visitParent == false || visitor(stack, info))
+			if (visitParent == false || visitor(stack))
 			{
-				ppids.append(PIDS_VAL(PidItemIndex, s_int, stack, info));
+				ppids.append(PIDS_VAL(PidItemIndex, s_int, stack));
 			}
 		}
-		else if (ppids.contains(ppid) && visitor(stack, info))
+		else if (ppids.contains(ppid) && visitor(stack))
 		{
-			ppids.append(PIDS_VAL(PidItemIndex, s_int, stack, info));
+			ppids.append(PIDS_VAL(PidItemIndex, s_int, stack));
 		}
 	}
 
