@@ -1,7 +1,7 @@
 /*
  * LinuxNetworkFunctions.h - declaration of LinuxNetworkFunctions class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -31,9 +31,12 @@
 class LinuxNetworkFunctions : public PlatformNetworkFunctions
 {
 public:
-	bool ping( const QString& hostAddress ) override;
+	PingResult ping(const QString& hostAddress) override;
 	bool configureFirewallException( const QString& applicationPath, const QString& description, bool enabled ) override;
 
 	bool configureSocketKeepalive( Socket socket, bool enabled, int idleTime, int interval, int probes ) override;
 
+	QNetworkInterface defaultRouteNetworkInterface() override;
+	int networkInterfaceSpeedInMBitPerSecond(const QNetworkInterface& networkInterface) override;
+
 };
