@@ -1,7 +1,7 @@
 /*
  * LinuxPlatformPlugin.h - declaration of LinuxPlatformPlugin class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -116,6 +116,9 @@ public:
 
 	ConfigurationPage* createConfigurationPage() override;
 
+	static void abort(int signal);
+	static QString formattedBacktraceString();
+
 private:
 	LinuxCoreFunctions m_linuxCoreFunctions{};
 	LinuxFilesystemFunctions m_linuxFilesystemFunctions{};
