@@ -1,7 +1,7 @@
 /*
  * LinuxServiceFunctions.cpp - implementation of LinuxServerProcess class
  *
- * Copyright (c) 2021-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2021-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -25,7 +25,9 @@
 #include <QFileInfo>
 
 #include <csignal>
+#ifdef HAVE_LIBPROCPS
 #include <proc/readproc.h>
+#endif
 #include <sys/errno.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -97,10 +99,9 @@ void LinuxServerProcess::stop()
 				},
 				pid, 0, true );
 #elif defined(HAVE_LIBPROC2)
-			LinuxCoreFunctions::forEachChildProcess([=](const pids_stack* stack, const pids_info* info)
+			LinuxCoreFunctions::forEachChildProcess([=](const pids_stack* stack)
 			{
-				Q_UNUSED(info)
-				const pid_t tid = PIDS_VAL(0, s_int, stack, info);
+				const pid_t tid = PIDS_VAL(0, s_int, stack);
 				if (tid > 0 && ::kill(tid, sig) < 0 && errno != ESRCH)
 				{
 					vCritical() << "kill() failed with" << errno;
