@@ -1,7 +1,7 @@
 /*
  * LinuxServiceFunctions.cpp - implementation of LinuxServiceFunctions class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -277,7 +277,7 @@ void LinuxServiceCore::stopServer( const QString& sessionPath )
 
 	vInfo() << "stopping server for removed session" << sessionPath;
 
-	auto serverProcess = qAsConst(m_serverProcesses)[sessionPath];
+	auto serverProcess = std::as_const(m_serverProcesses)[sessionPath];
 	serverProcess->disconnect(this);
 	serverProcess->stop();
 	serverProcess->deleteLater();
@@ -306,4 +306,13 @@ void LinuxServiceCore::checkSessionState( const QString& sessionPath )
 		vDebug() << "Stopping server for currently closing session" << sessionPath;
 		stopServer( sessionPath );
 	}
+	else
+	{
+		// restart server if crashed
+		const auto serverProcess = m_serverProcesses.value(sessionPath);
+		if (serverProcess && serverProcess->state() == QProcess::NotRunning)
+		{
+			QTimer::singleShot(ServerRestartInterval, serverProcess, [serverProcess]() { serverProcess->start(); });
+		}
+	}
 }
