@@ -1,7 +1,7 @@
 /*
  *  RemoteAccessWidget.cpp - widget containing a VNC-view and controls for it
  *
- *  Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
+ *  Copyright (c) 2006-2025 Tobias Junghans <tobydox@veyon.io>
  *
  *  This file is part of Veyon - https://veyon.io
  *
@@ -53,14 +53,10 @@ RemoteAccessWidgetToolBar::RemoteAccessWidgetToolBar( RemoteAccessWidget* parent
 	m_selectScreenButton( new ToolButton( QPixmap( QStringLiteral(":/remoteaccess/preferences-system-windows-effect-desktopgrid.png") ), tr( "Select screen" ) ) ),
 	m_sendShortcutButton( new ToolButton( QPixmap( QStringLiteral(":/remoteaccess/preferences-desktop-keyboard.png") ), tr( "Send shortcut" ) ) ),
 	m_screenshotButton( new ToolButton( QPixmap( QStringLiteral(":/remoteaccess/camera-photo.png") ), tr( "Screenshot" ) ) ),
-	m_fullScreenButton( new ToolButton( QPixmap( QStringLiteral(":/remoteaccess/view-fullscreen.png") ), tr( "Fullscreen" ), tr( "Window" ) ) ),
+	m_fullScreenButton( new ToolButton( QPixmap( QStringLiteral(":/core/view-fullscreen.png") ), tr( "Fullscreen" ), tr( "Window" ) ) ),
 	m_exitButton( new ToolButton( QPixmap( QStringLiteral(":/remoteaccess/application-exit.png") ), tr( "Exit" ) ) ),
 	m_screenSelectActions( new QActionGroup(this) )
 {
-	QPalette pal = palette();
-	pal.setBrush( QPalette::Window, QPixmap( QStringLiteral(":/core/toolbar-background.png") ) );
-	setPalette( pal );
-
 	setAttribute( Qt::WA_NoSystemBackground, true );
 	move( 0, 0 );
 	show();
@@ -138,7 +134,7 @@ RemoteAccessWidgetToolBar::RemoteAccessWidgetToolBar( RemoteAccessWidget* parent
 	layout->addWidget( m_exitButton );
 	layout->addSpacing( 5 );
 
-	setFixedHeight( m_exitButton->height() );
+	setFixedHeight(m_exitButton->minimumSizeHint().height());
 
 	connect( &m_showHideTimeLine, &QTimeLine::valueChanged, this, &RemoteAccessWidgetToolBar::updatePosition );
 
@@ -226,7 +222,7 @@ void RemoteAccessWidgetToolBar::paintEvent( QPaintEvent *paintEv )
 	f.setBold( true );
 	p.setFont( f );
 
-	p.setPen( QColor( 192, 192, 192 ) );
+	p.setPen(palette().color(QPalette::Text));
 	p.drawText( height() / 2, height() / 2 + fontMetrics().height() / 2,
 				m_parent->vncView() && m_parent->vncView()->connection() &&
 						m_parent->vncView()->connection()->state() == VncConnection::State::Connected ?
@@ -527,13 +523,13 @@ void RemoteAccessWidget::updateRemoteAccessTitle()
 
 	if (username.isEmpty() )
 	{
-		setWindowTitle( tr( "%1 - %2 Remote Access" ).arg( m_computerControlInterface->computer().name(),
-														   VeyonCore::applicationName() ) );
+		setWindowTitle(tr("%1 - %2 Remote Access").arg(m_computerControlInterface->computerName(),
+													   VeyonCore::applicationName()));
 	}
 	else
 	{
-		setWindowTitle( tr( "%1 - %2 - %3 Remote Access" ).arg( username,
-																m_computerControlInterface->computer().name(),
-																VeyonCore::applicationName() ) );
+		setWindowTitle(tr("%1 - %2 - %3 Remote Access").arg(username,
+															m_computerControlInterface->computerName(),
+															VeyonCore::applicationName()));
 	}
 }
