@@ -1,7 +1,7 @@
 /*
  * LogoffEventFilter.cpp - implementation of LogoffEventFilter class
  *
- * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -52,7 +52,7 @@ LogoffEventFilter::LogoffEventFilter() :
 
 
 
-bool LogoffEventFilter::nativeEventFilter( const QByteArray& eventType, void* message, long* result )
+bool LogoffEventFilter::nativeEventFilter(const QByteArray& eventType, void* message, qintptr* result)
 {
 	Q_UNUSED(eventType);
 	Q_UNUSED(result);
