@@ -1,7 +1,7 @@
 /*
  * LogoffEventFilter.h - declaration of LogoffEventFilter class
  *
- * Copyright (c) 2018-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2018-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -34,7 +34,7 @@ class LogoffEventFilter : public QAbstractNativeEventFilter
 public:
 	LogoffEventFilter();
 
-	bool nativeEventFilter( const QByteArray& eventType, void* message, long* result) override;
+	bool nativeEventFilter(const QByteArray& eventType, void* message, qintptr* result) override;
 
 private:
 	HANDLE m_shutdownEventHandle;
