@@ -1,7 +1,7 @@
 /*
  * WebApiController.cpp - implementation of WebApiController class
  *
- * Copyright (c) 2020-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2020-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -22,45 +22,19 @@
  *
  */
 
+#include <QTcpSocket>
 #include <QBuffer>
 #include <QEventLoop>
 #include <QImageWriter>
 
 #include "ComputerControlInterface.h"
 #include "FeatureManager.h"
-#include "PlatformSessionFunctions.h"
+#include "PlatformNetworkFunctions.h"
 #include "WebApiAuthenticationProxy.h"
 #include "WebApiConfiguration.h"
 #include "WebApiController.h"
 
 
-static void runInMainThread( const std::function<void()>& functor )
-{
-	if( QThread::currentThread() != VeyonCore::instance()->thread() )
-	{
-		QMetaObject::invokeMethod( VeyonCore::instance(), functor, Qt::BlockingQueuedConnection );
-	}
-	else
-	{
-		functor();
-	}
-}
-
-
-template<class T>
-static T runInMainThread( const std::function<T()>& functor )
-{
-	if( QThread::currentThread() != VeyonCore::instance()->thread() )
-	{
-		T retval{};
-		QMetaObject::invokeMethod( VeyonCore::instance(), functor, Qt::BlockingQueuedConnection, &retval );
-		return retval;
-	}
-
-	return functor();
-}
-
-
 static QString uuidToString( QUuid uuid )
 {
 #if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
@@ -76,6 +50,15 @@ WebApiController::WebApiController( const WebApiConfiguration& configuration, QO
 	m_configuration( configuration ),
 	m_connectionsLock( QReadWriteLock::Recursive )
 {
+	connect(&m_updateStatisticsTimer, &QTimer::timeout, this, &WebApiController::updateStatistics);
+	m_updateStatisticsTimer.start(StatisticsUpdateIntervalSeconds * MillisecondsPerSecond);
+
+	m_workerThread = new QThread(this);
+	m_workerThread->setObjectName(QStringLiteral("WebApiController Worker"));
+	m_workerThread->start();
+
+	m_workerObject = new QObject;
+	m_workerObject->moveToThread(m_workerThread);
 }
 
 
@@ -89,9 +72,34 @@ WebApiController::~WebApiController()
 
 
 
+WebApiController::Response WebApiController::getHostState(const Request& request, const QString& host)
+{
+	Q_UNUSED(request);
+
+	m_apiTotalRequestsCounter++;
+
+	QTcpSocket socket;
+	socket.connectToHost(host, VeyonCore::config().veyonServerPort());
+	if (socket.waitForConnected(3000))
+	{
+		return QVariantMap{{k2s(Key::State), QByteArrayLiteral("online")}};
+	}
+
+	if (VeyonCore::platform().networkFunctions().ping(host) == PlatformNetworkFunctions::PingResult::ReplyReceived)
+	{
+		return QByteArrayLiteral("up");
+	}
+
+	return QVariantMap{{k2s(Key::State), QByteArrayLiteral("down")}};
+}
+
+
+
 
 WebApiController::Response WebApiController::getAuthenticationMethods( const Request& request, const QString& host )
 {
+	m_apiTotalRequestsCounter++;
+
 	Q_UNUSED(request)
 
 	WebApiConnection connection( host.isEmpty() ? QStringLiteral("localhost") : host );
@@ -130,6 +138,8 @@ WebApiController::Response WebApiController::getAuthenticationMethods( const Req
 
 WebApiController::Response WebApiController::performAuthentication( const Request& request, const QString& host )
 {
+	m_apiTotalRequestsCounter++;
+
 	QReadLocker connectionsReadLocker{&m_connectionsLock};
 
 	if( m_connections.size() >= m_configuration.connectionLimit() )
@@ -154,15 +164,14 @@ WebApiController::Response WebApiController::performAuthentication( const Reques
 	auto proxy = new WebApiAuthenticationProxy( m_configuration );
 
 	// create connection (including timer resources) in main thread
-	auto connection = runInMainThread<WebApiConnectionPointer>( [host, proxy]() {
+	auto connection = runInWorkerThread<WebApiConnectionPointer>([this, host, proxy]() {
 		auto connection = new WebApiConnection{host.isEmpty() ? QStringLiteral("localhost") : host};
-		connection->controlInterface()->start( {}, ComputerControlInterface::UpdateMode::Basic, proxy );
+		connection->controlInterface()->start({}, ComputerControlInterface::UpdateMode::Basic, proxy);
 
-		// make shared pointer destroy the connection in main thread again
-		return WebApiConnectionPointer{ connection,
-										[]( WebApiConnection* c ) { runInMainThread( [c] { delete c; } ); }
-		};
-	} );
+		// make shared pointer destroy the connection in management thread again
+		return WebApiConnectionPointer{connection,
+						  [this](WebApiConnection* c) { runInWorkerThreadNonBlocking([c] { delete c; }); } };
+	});
 
 	const auto authTimeout = m_configuration.connectionAuthenticationTimeout() * MillisecondsPerSecond;
 	if( proxy->waitForAuthenticationMethods( authTimeout ) == false )
@@ -215,28 +224,39 @@ WebApiController::Response WebApiController::performAuthentication( const Reques
 
 	if( result )
 	{
-		LockingConnectionPointer connectionLock{connection};
+		connection->lock();
 
 		m_connectionsLock.lockForWrite();
 		m_connections[uuid] = connection;
 		m_connectionsLock.unlock();
 
+		connect(connection->controlInterface().get(), &ComputerControlInterface::framebufferUpdated,
+				this, &WebApiController::incrementVncFramebufferUpdatesCounter);
+
 		const auto idleTimer = connection->idleTimer();
 		const auto lifetimeTimer = connection->lifetimeTimer();
 
-		connect( idleTimer, &QTimer::timeout, this, [this, uuid]() { removeConnection( uuid ); } );
-		connect( lifetimeTimer, &QTimer::timeout, this, [this, uuid]() { removeConnection( uuid ); } );
+		connect( idleTimer, &QTimer::timeout, this, [this, uuid]() {
+			vInfo() << "idle time exceeded for connection" << uuid;
+			removeConnection(uuid);
+		} );
+		connect( lifetimeTimer, &QTimer::timeout, this, [this, uuid]() {
+			vInfo() << "lifetime exceeded for connection" << uuid;
+			removeConnection(uuid);
+		} );
 
 		const auto connectionIdleTimeout = m_configuration.connectionIdleTimeout() * MillisecondsPerSecond;
 		const auto connectionLifetime = m_configuration.connectionLifetime() * MillisecondsPerHour;
 
-		runInMainThread( [=] {
-			idleTimer->start( connectionIdleTimeout );
-			lifetimeTimer->start( connectionLifetime );
-		} );
+		connection->unlock();
+
+		runInWorkerThread([=] {
+			idleTimer->start(connectionIdleTimeout);
+			lifetimeTimer->start(connectionLifetime);
+		});
 
 		return QVariantMap{
-			{ connectionUidHeaderFieldName().toLower(), uuidToString( uuid ) },
+			{ QString::fromUtf8(connectionUidHeaderFieldName().toLower()), uuidToString(uuid) },
 			{ k2s(Key::ValidUntil), QDateTime::currentSecsSinceEpoch() + connectionLifetime / MillisecondsPerSecond }
 		};
 	}
@@ -248,6 +268,8 @@ WebApiController::Response WebApiController::performAuthentication( const Reques
 
 WebApiController::Response WebApiController::closeConnection( const Request& request, const QString& host )
 {
+	m_apiTotalRequestsCounter++;
+
 	Q_UNUSED(host)
 
 	Response checkResponse{};
@@ -256,7 +278,7 @@ WebApiController::Response WebApiController::closeConnection( const Request& req
 		return checkResponse;
 	}
 
-	removeConnection( lookupHeaderField(request.headers, connectionUidHeaderFieldName()).toUuid() );
+	removeConnection(QUuid{lookupHeaderField(request, connectionUidHeaderFieldName())});
 
 	return {};
 }
@@ -265,6 +287,8 @@ WebApiController::Response WebApiController::closeConnection( const Request& req
 
 WebApiController::Response WebApiController::getFramebuffer( const Request& request )
 {
+	m_apiTotalRequestsCounter++;
+
 	Response checkResponse{};
 	if( ( checkResponse = checkConnection( request ) ).error != Error::NoError )
 	{
@@ -278,6 +302,8 @@ WebApiController::Response WebApiController::getFramebuffer( const Request& requ
 		return Error::FramebufferNotAvailable;
 	}
 
+	m_framebufferRequestsCounter++;
+
 	const auto width = request.data[k2s(Key::Width)].toInt();
 	const auto height = request.data[k2s(Key::Height)].toInt();
 	const auto size = connection->scaledFramebufferSize( width, height );
@@ -310,6 +336,8 @@ WebApiController::Response WebApiController::getFramebuffer( const Request& requ
 
 WebApiController::Response WebApiController::listFeatures( const Request& request )
 {
+	m_apiTotalRequestsCounter++;
+
 	Response checkResponse{};
 	if( ( checkResponse = checkConnection( request ) ).error != Error::NoError )
 	{
@@ -338,6 +366,8 @@ WebApiController::Response WebApiController::listFeatures( const Request& reques
 
 WebApiController::Response WebApiController::setFeatureStatus( const Request& request, const QString& feature )
 {
+	m_apiTotalRequestsCounter++;
+
 	Response checkResponse{};
 	if( ( checkResponse = checkConnection( request ) ).error != Error::NoError ||
 		( checkResponse = checkFeature( feature ) ).error != Error::NoError )
@@ -356,8 +386,8 @@ WebApiController::Response WebApiController::setFeatureStatus( const Request& re
 																	 : FeatureProviderInterface::Operation::Stop;
 	const auto arguments = request.data[k2s(Key::Arguments)].toMap();
 
-	runInMainThread([&] {
-		VeyonCore::featureManager().controlFeature(feature, operation, arguments, {connection->controlInterface()});
+	runInWorkerThread([&] {
+		VeyonCore::featureManager().controlFeature(Feature::Uid{feature}, operation, arguments, {connection->controlInterface()});
 	});
 
 	return {};
@@ -367,6 +397,8 @@ WebApiController::Response WebApiController::setFeatureStatus( const Request& re
 
 WebApiController::Response WebApiController::getFeatureStatus( const Request& request, const QString& feature )
 {
+	m_apiTotalRequestsCounter++;
+
 	Response checkResponse{};
 	if( ( checkResponse = checkConnection( request ) ).error != Error::NoError )
 	{
@@ -376,7 +408,7 @@ WebApiController::Response WebApiController::getFeatureStatus( const Request& re
 	const auto connection = lookupConnection( request );
 	const auto controlInterface = connection->controlInterface();
 
-	const auto result = controlInterface->activeFeatures().contains( feature );
+	const auto result = controlInterface->activeFeatures().contains(Feature::Uid{feature});
 
 	return QVariantMap{ { k2s(Key::Active), result } };
 }
@@ -385,6 +417,8 @@ WebApiController::Response WebApiController::getFeatureStatus( const Request& re
 
 WebApiController::Response WebApiController::getUserInformation( const Request& request )
 {
+	m_apiTotalRequestsCounter++;
+
 	Response checkResponse{};
 	if( ( checkResponse = checkConnection( request ) ).error != Error::NoError )
 	{
@@ -396,22 +430,111 @@ WebApiController::Response WebApiController::getUserInformation( const Request&
 
 	const auto& userLoginName = controlInterface->userLoginName();
 	auto userFullName = controlInterface->userFullName();
-	auto sessionId = controlInterface->userSessionId();
-	if( userLoginName.isEmpty() )
+	if (userLoginName.isEmpty())
 	{
 		userFullName.clear();
-		sessionId = PlatformSessionFunctions::InvalidSessionId;
 	}
 
-	return QVariantMap{ {
-		{ k2s(Key::Login), userLoginName },
-		{ k2s(Key::FullName), userFullName },
-		{ k2s(Key::Session), sessionId }
-	} };
+	return QVariantMap{
+		{
+			{k2s(Key::Login), userLoginName},
+			{k2s(Key::FullName), userFullName}
+		}
+	};
 }
 
 
 
+WebApiController::Response WebApiController::getSessionInformation(const Request& request)
+{
+	m_apiTotalRequestsCounter++;
+
+	Response checkResponse{};
+	if((checkResponse = checkConnection(request)).error != Error::NoError)
+	{
+		return checkResponse;
+	}
+
+	const auto connection = lookupConnection(request);
+	const auto controlInterface = connection->controlInterface();
+
+	return QVariantMap{
+		{
+			{k2s(Key::SessionId), controlInterface->sessionInfo().id},
+			{k2s(Key::SessionUptime), controlInterface->sessionInfo().uptime},
+			{k2s(Key::SessionClientAddress), controlInterface->sessionInfo().clientAddress},
+			{k2s(Key::SessionClientName), controlInterface->sessionInfo().clientName},
+			{k2s(Key::SessionHostName), controlInterface->sessionInfo().hostName},
+		}
+	};
+}
+
+
+
+QString WebApiController::getStatistics()
+{
+	QReadLocker connectionsLocker{&m_connectionsLock};
+
+	return QStringLiteral("Total API requests: %1 (%2/s in the past %3 s)\n<br/>").arg(m_apiTotalRequestsCounter).arg(m_apiTotalRequestsPerSecond).arg(StatisticsUpdateIntervalSeconds) +
+			QStringLiteral("Framebuffer requests: %1 (%2/s in the past %3 s)\n<br/>").arg(m_framebufferRequestsCounter).arg(m_framebufferRequestsPerSecond).arg(StatisticsUpdateIntervalSeconds) +
+			QStringLiteral("VNC framebuffer updates: %1 (%2/s in the past %3 s)\n<br/>").arg(m_vncFramebufferUpdatesCounter).arg(m_vncFramebufferUpdatesPerSecond).arg(StatisticsUpdateIntervalSeconds) +
+			QStringLiteral("Number of client connections: %1<br/>\n").arg(m_connections.count());
+}
+
+
+
+QString WebApiController::getConnectionDetails()
+{
+	QReadLocker connectionsLocker{&m_connectionsLock};
+
+	QStringList columns {QStringLiteral("Connection UUID"),
+					   QStringLiteral("State"),
+					   QStringLiteral("Host"),
+					   QStringLiteral("User"),
+					   QStringLiteral("Server version")
+					  };
+	QList<QStringList> rows;
+	rows.reserve(m_connections.count());
+	for (auto it = m_connections.constBegin(), end = m_connections.constEnd(); it != end; ++it)
+	{
+		const auto connection = it.value();
+
+		rows.append({uuidToString(it.key()),
+					 EnumHelper::toString(connection->controlInterface()->state()),
+					 connection->controlInterface()->computer().hostName(),
+					 connection->controlInterface()->userLoginName(),
+					 EnumHelper::toString(connection->controlInterface()->serverVersion()),
+					});
+	}
+
+	const auto rowToString = [](const QStringList& row, const QString& tag) {
+		return std::accumulate(row.constBegin(), row.constEnd(), QString{}, [&tag](const QString& acc, const QString& cell) -> QString {
+			return acc + QStringLiteral("<%1>%2</%1>").arg(tag, cell);
+		});
+	};
+
+	const auto tableHeader = QStringLiteral("<tr>%1</tr>\n").arg(rowToString(columns, QStringLiteral("th")));
+	const auto tableBody = std::accumulate(rows.constBegin(), rows.constEnd(), QString{},
+										   [&](const QString& acc, const QStringList& row) -> QString {
+		return acc + QStringLiteral("<tr>%1</tr>\n").arg(rowToString(row, QStringLiteral("td")));
+	});
+
+	return QStringLiteral("<table border=\"1\">\n%1%2</table>\n").arg(tableHeader, tableBody);
+}
+
+
+
+WebApiController::Response WebApiController::sleep(const Request& request, const int& seconds) // clazy:exclude=function-args-by-value
+{
+	Q_UNUSED(request)
+
+	m_apiTotalRequestsCounter++;
+	QThread::sleep(seconds);
+
+	return {""};
+}
+
+
 QString WebApiController::errorString( WebApiController::Error error )
 {
 	switch( error )
@@ -436,32 +559,85 @@ QString WebApiController::errorString( WebApiController::Error error )
 
 
 
-void WebApiController::removeConnection( QUuid connectionUuid )
+void WebApiController::runInWorkerThread(const std::function<void()>& functor) const
 {
-	// destroy connection in main thread
-	runInMainThread( [=] {
-		QWriteLocker connectionsWriteLocker{ &m_connectionsLock };
-
-		m_connections.remove( connectionUuid );
-	} );
+	QMetaObject::invokeMethod(m_workerObject, functor, Qt::BlockingQueuedConnection);
 }
 
 
 
-QVariant WebApiController::lookupHeaderField(const Request& request, const QString& fieldName)
+void WebApiController::runInWorkerThreadNonBlocking(const std::function<void()>& functor) const
 {
-	if( request.headers.contains(fieldName) )
-	{
-		return request.headers[fieldName];
-	}
+	QMetaObject::invokeMethod(m_workerObject, functor, Qt::QueuedConnection);
+}
 
-	for( auto it = request.headers.constBegin(), end = request.headers.constEnd(); it != end; ++it )
+
+
+template<class T>
+T WebApiController::runInWorkerThread(const std::function<T()>& functor) const
+{
+	T retval{};
+	QMetaObject::invokeMethod(m_workerObject, functor, Qt::BlockingQueuedConnection, &retval );
+	return retval;
+}
+
+
+
+void WebApiController::removeConnection( QUuid connectionUuid )
+{
+	QWriteLocker connectionsWriteLocker{ &m_connectionsLock };
+
+	// deleter functor automatically performs actual deletion in worker thread
+	m_connections.remove(connectionUuid);
+}
+
+
+
+void WebApiController::incrementVncFramebufferUpdatesCounter()
+{
+	++m_vncFramebufferUpdatesCounter;
+}
+
+
+
+void WebApiController::updateStatistics()
+{
+	m_apiTotalRequestsPerSecond = (m_apiTotalRequestsCounter - m_apiTotalRequestsLast) / StatisticsUpdateIntervalSeconds;
+	m_framebufferRequestsPerSecond = (m_framebufferRequestsCounter - m_framebufferRequestsLast) / StatisticsUpdateIntervalSeconds;
+	m_vncFramebufferUpdatesPerSecond = (m_vncFramebufferUpdatesCounter - m_vncFramebufferUpdatesLast) / StatisticsUpdateIntervalSeconds;
+
+	m_apiTotalRequestsLast = m_apiTotalRequestsCounter;
+	m_framebufferRequestsLast = m_framebufferRequestsCounter;
+	m_vncFramebufferUpdatesLast = m_vncFramebufferUpdatesCounter;
+}
+
+
+
+QByteArray WebApiController::lookupHeaderField(const Request& request, const QByteArray& fieldName)
+{
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+	for (const auto& h : request.headers)
 	{
-		if( it.key().compare( fieldName, Qt::CaseInsensitive ) == 0 )
+		if (h.first.compare(fieldName, Qt::CaseInsensitive) == 0)
 		{
-			return it.value();
+			return h.second;
 		}
 	}
+#else
+	const auto fieldNameString = QString::fromUtf8(fieldName);
+	if (request.headers.contains(fieldNameString))
+	{
+		return request.headers[fieldNameString].toByteArray();
+	}
+
+	for (auto it = request.headers.constBegin(), end = request.headers.constEnd(); it != end; ++it)
+	{
+		if (it.key().compare(fieldNameString, Qt::CaseInsensitive ) == 0)
+		{
+			return it.value().toByteArray();
+		}
+	}
+#endif
 
 	return {};
 }
@@ -472,16 +648,16 @@ WebApiController::LockingConnectionPointer WebApiController::lookupConnection( c
 {
 	QReadLocker connectionsReadLocker{&m_connectionsLock};
 
-	return m_connections.value( lookupHeaderField(request.headers, connectionUidHeaderFieldName()).toUuid() );
+	return m_connections.value(QUuid{lookupHeaderField(request, connectionUidHeaderFieldName())});
 }
 
 
 
 WebApiController::Response WebApiController::checkConnection( const Request& request )
 {
-	const auto connectionUuid = lookupHeaderField(request.headers, connectionUidHeaderFieldName()).toUuid();
+	const QUuid connectionUuid{lookupHeaderField(request, connectionUidHeaderFieldName())};
 
-	return runInMainThread<WebApiController::Response>( [=]() -> WebApiController::Response {
+	return runInWorkerThread<WebApiController::Response>([=]() -> WebApiController::Response {
 		m_connectionsLock.lockForRead();
 		if( connectionUuid.isNull() || m_connections.contains( connectionUuid ) == false )
 		{
@@ -489,7 +665,7 @@ WebApiController::Response WebApiController::checkConnection( const Request& req
 			return Error::InvalidConnection;
 		}
 
-		const auto connection = qAsConst(m_connections)[connectionUuid];
+		const auto connection = std::as_const(m_connections)[connectionUuid];
 		m_connectionsLock.unlock();
 
 		connection->lock();
@@ -508,7 +684,7 @@ WebApiController::Response WebApiController::checkConnection( const Request& req
 
 WebApiController::Response WebApiController::checkFeature( const QString& featureUid )
 {
-	if( VeyonCore::featureManager().feature( featureUid ).isValid() == false )
+	if( VeyonCore::featureManager().feature(Feature::Uid{featureUid}).isValid() == false )
 	{
 		return Error::InvalidFeature;
 	}
