@@ -1,7 +1,7 @@
 /*
  * ComputerControlServer.cpp - implementation of ComputerControlServer
  *
- * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -31,6 +31,7 @@
 #include "FeatureManager.h"
 #include "FeatureMessage.h"
 #include "HostAddress.h"
+#include "PlatformPluginInterface.h"
 #include "VeyonConfiguration.h"
 #include "SystemTrayIcon.h"
 
@@ -43,7 +44,7 @@ ComputerControlServer::ComputerControlServer( QObject* parent ) :
 	m_serverAuthenticationManager( this ),
 	m_serverAccessControlManager( m_featureWorkerManager, VeyonCore::builtinFeatures().desktopAccessDialog(), this ),
 	m_vncServer(),
-	m_vncProxyServer( VeyonCore::config().localConnectOnly() || AccessControlProvider().isAccessToLocalComputerDenied() ?
+	m_vncProxyServer( VeyonCore::config().localConnectOnly() || VeyonCore::builtinFeatures().accessControlProvider().isAccessToLocalComputerDenied() ?
 						  QHostAddress::LocalHost : QHostAddress::Any,
 					  VeyonCore::config().veyonServerPort() + VeyonCore::sessionId(),
 					  this,
@@ -142,12 +143,9 @@ bool ComputerControlServer::sendFeatureMessageReply( const MessageContext& conte
 {
 	vDebug() << reply;
 
-	if( context.ioDevice() )
+	if (context.ioDevice())
 	{
-		char rfbMessageType = FeatureMessage::RfbMessageType;
-		context.ioDevice()->write( &rfbMessageType, sizeof(rfbMessageType) );
-
-		return reply.send( context.ioDevice() );
+		return reply.sendAsRfbMessage(context.ioDevice());
 	}
 
 	return false;
@@ -169,8 +167,8 @@ void ComputerControlServer::setMinimumFramebufferUpdateInterval(const MessageCon
 void ComputerControlServer::checkForIncompleteAuthentication( VncServerClient* client )
 {
 	// connection to client closed during authentication?
-	if( client->protocolState() == VncServerProtocol::AuthenticationTypes ||
-		client->protocolState() == VncServerProtocol::Authenticating )
+	if( client->protocolState() == VncServerProtocol::State::AuthenticationTypes ||
+		client->protocolState() == VncServerProtocol::State::Authenticating )
 	{
 		// then mark as failed authentication and report it
 		client->setAuthState( VncServerClient::AuthState::Failed );
@@ -187,7 +185,8 @@ void ComputerControlServer::showAuthenticationMessage( VncServerClient* client )
 	{
 		vWarning() << "Authentication failed for" << client->hostAddress() << client->username();
 
-		if( VeyonCore::config().failedAuthenticationNotificationsEnabled() )
+		if (VeyonCore::config().failedAuthenticationNotificationsEnabled() &&
+			VeyonCore::platform().sessionFunctions().currentSessionHasUser())
 		{
 			QMutexLocker l( &m_dataMutex );
 
@@ -216,7 +215,8 @@ void ComputerControlServer::showAccessControlMessage( VncServerClient* client )
 	{
 		vInfo() << "Access control successful for" << client->hostAddress() << client->username();
 
-		if( VeyonCore::config().remoteConnectionNotificationsEnabled() )
+		if (VeyonCore::config().remoteConnectionNotificationsEnabled() &&
+			VeyonCore::platform().sessionFunctions().currentSessionHasUser())
 		{
 			const auto fqdn = HostAddress( client->hostAddress() ).tryConvert( HostAddress::Type::FullyQualifiedDomainName );
 
@@ -287,6 +287,11 @@ void ComputerControlServer::sendAsyncFeatureMessages(VncProxyConnection* connect
 
 void ComputerControlServer::updateTrayIconToolTip()
 {
+	if (VeyonCore::platform().sessionFunctions().currentSessionHasUser() == false)
+	{
+		return;
+	}
+
 	auto toolTip = tr( "%1 Service %2 at %3:%4" ).arg( VeyonCore::applicationName(), VeyonCore::versionString(),
 													   HostAddress::localFQDN(),
 												QString::number( VeyonCore::config().veyonServerPort() + VeyonCore::sessionId() ) );
