@@ -1,7 +1,7 @@
 /*
  * ServerAccessControlManager.cpp - implementation of ServerAccessControlManager
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,11 +24,10 @@
 
 #include "VeyonCore.h"
 
+#include "BuiltinFeatures.h"
 #include "ServerAccessControlManager.h"
 #include "AccessControlProvider.h"
 #include "DesktopAccessDialog.h"
-#include "VeyonConfiguration.h"
-#include "VariantArrayMessage.h"
 
 
 ServerAccessControlManager::ServerAccessControlManager( FeatureWorkerManager& featureWorkerManager,
@@ -60,6 +59,7 @@ void ServerAccessControlManager::addClient( VncServerClient* client )
 	default:
 		// reject unknown auth type
 		client->setAccessControlState( VncServerClient::AccessControlState::Failed );
+		client->setAccessControlDetails(tr("Requested authentication method not available"));
 		break;
 	}
 
@@ -81,7 +81,7 @@ void ServerAccessControlManager::removeClient( VncServerClient* client )
 	const VncServerClientList previousClients = m_clients;
 	m_clients.clear();
 
-	for( auto prevClient : qAsConst( previousClients ) )
+	for( auto prevClient : std::as_const( previousClients ) )
 	{
 		prevClient->setAccessControlState( VncServerClient::AccessControlState::Init );
 		addClient( prevClient );
@@ -90,7 +90,7 @@ void ServerAccessControlManager::removeClient( VncServerClient* client )
 				prevClient->accessControlState() != VncServerClient::AccessControlState::Pending )
 		{
 			vDebug() << "closing connection as client does not pass access control any longer";
-			prevClient->setProtocolState( VncServerProtocol::Close );
+			prevClient->setProtocolState( VncServerProtocol::State::Close );
 		}
 	}
 }
@@ -117,15 +117,19 @@ void ServerAccessControlManager::performAccessControl( VncServerClient* client )
 		break;
 	}
 
-	const auto accessResult =
-			AccessControlProvider().checkAccess( client->username(),
-												 client->hostAddress(),
-												 connectedUsers() );
+	const auto checkResult = VeyonCore::builtinFeatures().accessControlProvider()
+							 .checkAccess(client->username(),
+										  client->hostAddress(),
+										  connectedUsers());
 
-	switch( accessResult )
+	switch (checkResult.access)
 	{
 	case AccessControlProvider::Access::Allow:
 		client->setAccessControlState( VncServerClient::AccessControlState::Successful );
+		if (checkResult.matchedRule)
+		{
+			client->setAccessControlDetails(tr("Access allowed by rule \"%1\"").arg(checkResult.matchedRule->name()));
+		}
 		break;
 
 	case AccessControlProvider::Access::ToBeConfirmed:
@@ -134,7 +138,19 @@ void ServerAccessControlManager::performAccessControl( VncServerClient* client )
 
 	default:
 		client->setAccessControlState( VncServerClient::AccessControlState::Failed );
-		client->setProtocolState( VncServerProtocol::Close );
+		client->setProtocolState( VncServerProtocol::State::Close );
+		if (checkResult.reason == AccessControlProvider::Reason::AccessControlRuleMatched && checkResult.matchedRule)
+		{
+			client->setAccessControlDetails(tr("Access denied by rule \"%1\"").arg(checkResult.matchedRule->name()));
+		}
+		else if (checkResult.reason == AccessControlProvider::Reason::NoAccessControlRuleMatched)
+		{
+			client->setAccessControlDetails(tr("No rule allowed access"));
+		}
+		else if (checkResult.reason == AccessControlProvider::Reason::UserNotInAuthorizedUserGroups)
+		{
+			client->setAccessControlDetails(tr("Accessing user not member of an authorized user group"));
+		}
 		break;
 	}
 
@@ -150,11 +166,12 @@ VncServerClient::AccessControlState ServerAccessControlManager::confirmDesktopAc
 	// did we save a previous choice because user chose "always" or "never"?
 	if( m_desktopAccessChoices.contains( hostUserPair ) )
 	{
-		if( qAsConst(m_desktopAccessChoices)[hostUserPair] == DesktopAccessDialog::ChoiceAlways )
+		if( std::as_const(m_desktopAccessChoices)[hostUserPair] == DesktopAccessDialog::ChoiceAlways )
 		{
 			return VncServerClient::AccessControlState::Successful;
 		}
 
+		client->setAccessControlDetails(tr("User has denied access"));
 		return VncServerClient::AccessControlState::Failed;
 	}
 
@@ -205,12 +222,13 @@ void ServerAccessControlManager::finishDesktopAccessConfirmation( VncServerClien
 	if( choice == DesktopAccessDialog::ChoiceYes || choice == DesktopAccessDialog::ChoiceAlways )
 	{
 		client->setAccessControlState( VncServerClient::AccessControlState::Successful );
+		client->setAccessControlDetails(tr("User confirmed access"));
 		m_clients.append( client );
 	}
 	else
 	{
 		client->setAccessControlState( VncServerClient::AccessControlState::Failed );
-		client->setProtocolState( VncServerProtocol::Close );
+		client->setAccessControlDetails(tr("User has denied access"));
 	}
 }
 
