@@ -1,7 +1,7 @@
 /*
  * VncProxyConnection.cpp - class representing a connection within VncProxyServer
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -39,7 +39,6 @@ VncProxyConnection::VncProxyConnection( QTcpSocket* clientSocket,
 	m_proxyClientSocket( clientSocket ),
 	m_vncServerSocket( new QTcpSocket( this ) ),
 	m_rfbClientToServerMessageSizes( {
-		{ rfbSetPixelFormat, sz_rfbSetPixelFormatMsg },
 		{ rfbFramebufferUpdateRequest, sz_rfbFramebufferUpdateRequestMsg },
 		{ rfbKeyEvent, sz_rfbKeyEventMsg },
 		{ rfbPointerEvent, sz_rfbPointerEventMsg },
@@ -76,7 +75,7 @@ void VncProxyConnection::start()
 
 void VncProxyConnection::readFromClient()
 {
-	if( serverProtocol().state() != VncServerProtocol::Running )
+	if( serverProtocol().state() != VncServerProtocol::State::Running )
 	{
 		while( serverProtocol().read() ) // Flawfinder: ignore
 		{
@@ -99,7 +98,7 @@ void VncProxyConnection::readFromClient()
 		readFromClientLater();
 	}
 
-	if( serverProtocol().state() == VncServerProtocol::FramebufferInit &&
+	if( serverProtocol().state() == VncServerProtocol::State::FramebufferInit &&
 		clientProtocol().state() == VncClientProtocol::Disconnected )
 	{
 		m_vncServerSocket->connectToHost( QHostAddress::LocalHost, quint16(m_vncServerPort) );
@@ -130,7 +129,7 @@ void VncProxyConnection::readFromServer()
 			readFromServerLater();
 		}
 	}
-	else if( serverProtocol().state() == VncServerProtocol::Running )
+	else if( serverProtocol().state() == VncServerProtocol::State::Running )
 	{
 		while( receiveServerMessage() )
 		{
@@ -222,6 +221,23 @@ bool VncProxyConnection::receiveClientMessage()
 		}
 		break;
 
+	case rfbSetPixelFormat:
+		if (socket->bytesAvailable() >= sz_rfbSetPixelFormatMsg)
+		{
+			rfbSetPixelFormatMsg setPixelFormatMessage;
+			if (socket->peek(reinterpret_cast<char *>(&setPixelFormatMessage), sz_rfbSetPixelFormatMsg) == sz_rfbSetPixelFormatMsg)
+			{
+				auto format = setPixelFormatMessage.format;
+				format.redMax = qFromBigEndian(format.redMax);
+				format.greenMax = qFromBigEndian(format.greenMax);
+				format.blueMax = qFromBigEndian(format.blueMax);
+				clientProtocol().setPixelFormat(format);
+
+				return forwardDataToServer(sz_rfbSetPixelFormatMsg);
+			}
+		}
+		break;
+
 	default:
 		if( m_rfbClientToServerMessageSizes.contains( messageType ) == false )
 		{
