@@ -1,7 +1,7 @@
 /*
  * VncProxyConnection.h - class representing a connection within VncProxyServer
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,7 +24,7 @@
 
 #pragma once
 
-#include "VeyonCore.h"
+#include <QObject>
 
 class QBuffer;
 class QTcpSocket;
