@@ -1,7 +1,7 @@
 /*
  * VncProxyServer.cpp - a VNC proxy implementation for intercepting VNC connections
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -76,7 +76,7 @@ bool VncProxyServer::start( int vncServerPort, const Password& vncServerPassword
 
 void VncProxyServer::stop()
 {
-	for( auto connection : qAsConst( m_connections ) )
+	for( auto connection : std::as_const( m_connections ) )
 	{
 		delete connection;
 	}
